from .Base import Store
from enum import StrEnum, auto
from random import choice, randrange


class Antique(Store):
    @staticmethod
    def generate():
        n1 = [
            "A New View",
            "A Quiet Corner",
            "About Time",
            "Age of Vintage",
            "Aged Goodness",
            "Anecdotes",
            "Another Man's Treasures",
            "Another Treasures",
            "Antique Appeal",
            "Antique Cache",
            "Antique Cuties",
            "Antique Hut",
            "Antique Trove",
            "Antiques and Artifacts",
            "Antiquities",
            "Authentic Antiquities",
            "Beautiful Salvage",
            "Blasts from the Past",
            "Bought Again",
            "Bygones",
            "Checkered Pasts",
            "Cozy Collectibles",
            "Dinky and Dainty",
            "Discoveries",
            "Drab to Fab",
            "Echoes of the Past",
            "Established Goods",
            "Focus of the Past",
            "Focus on the Past",
            "Forget Me Nots",
            "Forgotten Furnishings",
            "Fortunes in Time",
            "Found in Time",
            "From Oblivion",
            "From Time Immemorial",
            "Frozen in Time",
            "General Goods",
            "Good As New",
            "Good Goods",
            "Good Ol' Days",
            "Hodge Podge Lodge",
            "Honest Heirlooms",
            "In-Of-Date",
            "Joys For Forever",
            "Junk Deluxe",
            "Just in Time",
            "Knick-knack Paddywhack Shack",
            "Legends of Their Time",
            "Little Collectibles",
            "Little House of Trinkets",
            "Live in the Past",
            "Living Memories",
            "Long Time No See",
            "Lost and Found in Time",
            "Matters of Time",
            "Memory Lane",
            "Miracles of the Past",
            "Mod Life",
            "Modern Memories",
            "Modern Vintage",
            "Needful Things",
            "Odd Types",
            "Old Gold",
            "Old Roots",
            "Old Stuff",
            "Old and Bold",
            "Oldies and Goldies",
            "Once upon a time",
            "One Time or Another",
            "Out of the Attic",
            "Pandora's Box",
            "Paragon Prizes",
            "Pass On the Past",
            "Pass The Time",
            "Past Caring",
            "Past Meets Present",
            "Past On",
            "Past Over",
            "Past Passed On",
            "Past Repast",
            "Pockets of Time",
            "Precious Past",
            "Precious Things",
            "Presents for the Present",
            "Presents of the Past",
            "Preserved",
            "Primes of the Past",
            "Rags and Riches",
            "Recent Memories",
            "Recollect Them All",
            "Recollectibles",
            "Relics and Rarities",
            "Relics and Riches",
            "Relics of Time",
            "Reliquary",
            "Remains to be Seen",
            "Remember",
            "Remember This",
            "Remember, Remember",
            "Renewed Life",
            "Renewed Memories",
            "Retro Relics",
            "Revered Relics",
            "Revival",
            "Salvage Garden",
            "Secrets of the Past",
            "Shared Memories",
            "Stuff and Things",
            "Sweet Memories",
            "Taken for Granted",
            "Tales Resold",
            "Tales of the Past",
            "Tales Retold",
            "Tales Untold",
            "Tests of Time",
            "The Antiki-Wiki",
            "The Antique Market",
            "The Salvage Beast",
            "The Shuffle of Things",
            "The Time is Ripe",
            "The Treasure Chest",
            "The Treasure Trove",
            "Things Past",
            "Things of the Past",
            "Thingymabobs",
            "Time Honored",
            "Time Not Forgotten",
            "Time Recovered",
            "Time of One's Life",
            "Timeless Treasures",
            "Timeless Trinkets",
            "Times Remembered",
            "Top Drawer Antiques",
            "Treasures and Trinkets",
            "Treasures of Time",
            "Treasure Trove",
            "Trinkets and Traditions",
            "Trinkets of Time",
            "Twosided",
            "Utter Clutter",
            "Vagabond Vendor",
            "Vestiges of the Past",
            "Vintage",
            "Vintage Baby",
            "Vintage Treasures",
            "Vintage Vogue",
            "Vintage Wares",
            "Warm Wares",
            "Wayward Wealths",
            "Wealth of Time",
            "Well of a Time",
            "Whispers of the Past",
            "Wonders of the Past",
        ]
        return choice(n1).title()


class Clothes(Store):
    @staticmethod
    def generate():
        c1 = [
            "A Change of Art",
            "A Cool Thread",
            "A Flair Deal",
            "A Stitch in Time",
            "A Wood Deal",
            "Air of Flair",
            "All's Flair",
            "And Sew Forth",
            "And Sew On",
            "Any Stitch Way",
            "Apothecrafty",
            "Art Beats",
            "Art Cookie",
            "Art From Scratch",
            "Art Tea",
            "Art Ways",
            "Art a la Carte",
            "Art and Parcel",
            "Art of Gold",
            "Art of the Furniture",
            "Artsy Fartsy",
            "Be Sew Bold",
            "Bear With Flair",
            "Beautique",
            "Beauty Embroidified",
            "By Design",
            "Care With Flair",
            "Care to Flair",
            "Celecreation",
            "Couture Gifts",
            "Craft Crazy",
            "Craft Fever",
            "Craft Machine",
            "Craftastical",
            "Crafter Hours",
            "Crafter-Noon Delights",
            "Crafterina",
            "Crafterpeneur",
            "Crafting Creativity",
            "Craftopia",
            "Crafts Foundry",
            "Craftworks",
            "Crafty Pleasures",
            "Create Mate",
            "Create Parade",
            "Created Comforts",
            "Creative Beat",
            "Creative Crafts",
            "Creative Creature",
            "Creative Motions",
            "Creative Scene",
            "Creative Splash",
            "Critter Crafts",
            "Critter Knitter",
            "Curio Crafts",
            "Cute as a Button",
            "Daily Thread",
            "Dangly Knits",
            "Definitely Knot",
            "Destined to Design",
            "Doodlecrafts",
            "Draft to Craft",
            "Dreamcrafts",
            "Etched On My Art",
            "Every Knit As Good",
            "Fab Fabrics",
            "Fabric Antics",
            "Fabric Magic",
            "First Create",
            "Flair Play",
            "Flair is Fair",
            "Flair to Share",
            "Flair to Spare",
            "Flights of Fancy",
            "Flying Art",
            "For Art's Sake",
            "For Keep's Sake",
            "For the Most Art",
            "From the Art",
            "Full Seam Ahead",
            "Giftsakes",
            "Go With the Sew",
            "Handy Craft",
            "Handy Handmades",
            "Handy Hands",
            "Happily Ever Crafter",
            "Happy Designs",
            "Heart in Art",
            "Heart to Home",
            "Heavenly Handmade",
            "Hot Threads",
            "I Got Crafts",
            "I Sew It",
            "In Good Hands",
            "In Stitches",
            "In These Arts",
            "In a Stitch",
            "Itching for Stitching",
            "Knit Fit",
            "Knit Knot",
            "Knit Picks",
            "Knit Wit",
            "Knit by Knit",
            "Knit for the Gods",
            "Knitter Critter",
            "Knot Always",
            "Knot Done",
            "Knot Impossible",
            "Knot Lost",
            "Knot a Bit",
            "Knotty Knitters",
            "Make, Believe",
            "Many Hands",
            "My Flair Lady",
            "Near to My Art",
            "Needle in a Haystack",
            "Nightcrafts",
            "No Haste, No Waste",
            "Of the Arts",
            "One Little Knit",
            "Out of the Box",
            "Piece of My Art",
            "Pieces of Art",
            "Pocket Crafts",
            "Pulse Art",
            "Right From the Art",
            "Robin Wood",
            "Seam Come True",
            "Seam On",
            "Seam With Pride",
            "Seam World",
            "Seam's Right",
            "Sew Crafty",
            "Sew Flow",
            "Sew It Goes",
            "Sew It Happens",
            "Sew Loveley",
            "Sew Pretty",
            "Sew Sinful",
            "Sew Solutions",
            "Sew and Saw",
            "Sew and Sell",
            "Sew and Sew",
            "Sew of Hands",
            "Sew the Story Goes",
            "Sewley",
            "Sinful Soaps",
            "Smart Art",
            "Snip Snap",
            "So Far, Sew Good",
            "Spun Fun",
            "State of Create",
            "Stensability",
            "Stitch Away",
            "Stitch Itch",
            "Stitch-Perfect",
            "Sum of my Arts",
            "Sweet Craftations",
            "Sweet Scents",
            "Sweet Seams",
            "Textile Aisle",
            "Textile Smile",
            "Textile Style",
            "Textilophile",
            "That's Sew Creative",
            "The Art Bard",
            "The Art Box",
            "The Art Cart",
            "The Big Ball of Yarn",
            "The Craft Circus",
            "The Craft Crustacean",
            "The Craft Draft",
            "The Craft Room",
            "The Craft Zone",
            "The Flair Bear",
            "The Flair Lair",
            "The Flairy",
            "The More You Bow",
            "The Needle 'n Thread",
            "The Seam Dream",
            "The Seam Theme",
            "The Sew Show",
            "The Sewing Room",
            "The Stitch Kettle",
            "The Stitch Witch",
            "The Thread 'n Needle",
            "The Unique Boutique",
            "Thread and Buttons",
            "Thread of Roses",
            "Threaded Needle",
            "Tins and Needles",
            "To Be Flair",
            "True Knit",
            "Whimsical Woods",
            "Whole Knit and Caboodle",
            "Wildest Seams",
            "Wood That I Could",
            "Would Craft",
            "You Craft What You Sew",
            "You Imbued",
        ]
        return choice(c1)


class Enchanter(Store):
    @staticmethod
    def generate():
        c1 = [
            "a",
            "e",
            "i",
            "o",
            "u",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
        ]
        c2 = [
            "b",
            "d",
            "k",
            "l",
            "m",
            "n",
            "p",
            "r",
            "s",
            "t",
            "b",
            "d",
            "f",
            "g",
            "h",
            "k",
            "l",
            "m",
            "n",
            "p",
            "r",
            "s",
            "t",
            "v",
            "w",
            "y",
            "z",
            "br",
            "dr",
            "gr",
            "kr",
            "pr",
            "str",
            "tr",
            "bl",
            "cl",
            "fl",
            "gl",
            "kl",
            "pl",
            "sl",
        ]
        c3 = [
            "a",
            "e",
            "i",
            "o",
            "u",
            "a",
            "e",
            "i",
            "o",
            "u",
            "ae",
            "ea",
            "ou",
            "au",
            "a",
            "e",
            "o",
        ]
        c4 = ["d", "f", "g", "k", "l", "m", "n", "p", "r", "s", "t", "x"]
        c5 = ["w", "n", "s", "m", "r", "", "", "", "", "", "", ""]
        c6 = [
            "any",
            "arry",
            "arth",
            "arths",
            "arts",
            "elts",
            "erra",
            "erry",
            "erth",
            "eth",
            "iams",
            "ia",
            "iara",
            "ine",
            "inns",
            "iths",
            "iton",
            "ity",
            "onia",
            "ons",
            "ora",
            "ore",
            "orth",
            "orths",
            "ose",
            "yce",
        ]
        c7 = [
            "Academy of Sorcery",
            "Academy of Spells",
            "Academy of Magics",
            "Academy of Witchcraft",
            "Academy of Wizardry",
            "Academy of the Arcane",
            "Institute of Magics",
            "Institute of Wizardy",
            "Institute of the Arcane",
            "School of Magics",
            "School of Sorcery",
            "School of Witchcraft",
            "School of Wizardry",
            "School of Wizards",
            "School of the Arcane",
        ]

        return str(
            choice(c1) + choice(c2) + choice(c3) + choice(c4) + choice(c5) + choice(c6) + ", " + choice(c7)
        ).title()


class Alchemist(Store):
    @staticmethod
    def generate():
        p1 = [
            "Abracapothecary",
            "Abrakadabra",
            "Ace High",
            "Angels and Demons",
            "Arcane Affinity",
            "Arcane Infinity",
            "Arcane Minded",
            "Augury and Alchemy",
            "Bona Fida",
            "Botanica Magica",
            "Breaking Point",
            "Celestial Spell",
            "Cures and Curses",
            "Darkness and Lightness",
            "Demons and Daemons",
            "Dispel and That Spell",
            "Doves and Pigeons",
            "Dragonfire",
            "Eagle's Eye",
            "Embers and Ashes",
            "Faerie Fire",
            "Fantasma",
            "Fortunes and Luck",
            "Genie's Lantern",
            "Genius in a Bottle",
            "Ghosts 'n Stuff",
            "Ghosts and Phantoms",
            "Gobl-Inn",
            "Gorgons and Gremlins",
            "Griffins and Gargoyles",
            "Heaven's Door",
            "Hell's Gate",
            "Herbs and Lotions",
            "Hexes and Jinxes",
            "Hocus Pocus",
            "Hocusses and Pocusses",
            "Horoscopes and Heroscopes",
            "Illuminations",
            "Invisibility and Invincibility",
            "Ki and Chi",
            "Nostrum Arcade",
            "Omnipharmacon",
            "Orbs and Talismans",
            "Palindrome",
            "Pandora",
            "Pandora's Box",
            "Pharmagician",
            "Pixie Dust",
            "Polymorph",
            "Portable Potents",
            "Potions and Cauldrons",
            "Potions and Lotions",
            "Rainbows and Sunshine",
            "Runes and Relics",
            "Runes and Rods",
            "Shades and Shadows",
            "Shifted Polarity",
            "Siphons and Souls",
            "Smoke and Mirrors",
            "Solutions",
            "Solutions and Answers",
            "Spellbound",
            "Spellunking",
            "Spheres and Orbs",
            "Sprites and Spirits",
            "Staves and Stoves",
            "Sticks and Stones",
            "Taboos and Voodoos",
            "Telekinesis and Telepathy",
            "The Acolyte",
            "The Alchemist",
            "The Animorph",
            "The Arcane Barrier",
            "The Arcane Gateway",
            "The Arcane Scroll",
            "The Archangel",
            "The Banished Beast",
            "The Banshee's Scream",
            "The Belly of the Beast",
            "The Black Couldron",
            "The Blink",
            "The Blissful Blizzard",
            "The Blood Pact",
            "The Bloodstone",
            "The Blue Moon",
            "The Book of Riddles",
            "The Bound Tome",
            "The Bramble Staff",
            "The Broken Vial",
            "The Cat In The Hat",
            "The Champion's Scroll",
            "The Charm",
            "The Cloak and Dagger",
            "The Cloak of Invisibility",
            "The Companion",
            "The Cone of Cold",
            "The Conjured Refreshment",
            "The Counterspell",
            "The Crystal Ball",
            "The Dark Flame",
            "The Daydream",
            "The Decoy",
            "The Devil's Key",
            "The Dew Drop",
            "The Double Whammy",
            "The Dragon Aspect",
            "The Dragon Dungeon",
            "The Dragon Seal",
            "The Dragon Slayer",
            "The Dragon's Breath",
            "The Dragonhide",
            "The Dusty Tome",
            "The Dwarven Beard",
            "The Ectoplasm",
            "The Elder Scroll",
            "The Elemental Fury",
            "The Equinox",
            "The Ethereal",
            "The Evil Eye",
            "The Eye of Newt",
            "The Falling Feather",
            "The Familiar",
            "The Faulty Dice",
            "The Fel Steed",
            "The Fifth Element",
            "The Final Form",
            "The Fireball",
            "The Flying Carpet",
            "The Force Field",
            "The Frosty Finger",
            "The Giant Gnome",
            "The Golden Lead",
            "The Grey Beard",
            "The Halberdashery",
            "The Holy Grail",
            "The Hourglass",
            "The Illusion",
            "The Last Spell",
            "The Laughing Leprichaun",
            "The Laughing Skull",
            "The Life Drain",
            "The Little Bunyip",
            "The Little Pixie",
            "The Living Statue",
            "The Magic Box",
            "The Magic Dart",
            "The Magnet",
            "The Minotaur Maze",
            "The Mirage",
            "The Mirror Image",
            "The Mistletoe",
            "The Mithril Mantle",
            "The Mystery",
            "The Mystic Mythic",
            "The Nether and Void",
            "The Nightmare",
            "The Ninth Life",
            "The Pegasus",
            "The Pestle and Mortar",
            "The Philosopher's Stone",
            "The Phoenix Feather",
            "The Plane Walker",
            "The Portal",
            "The Prophecy",
            "The Quiet Ritual",
            "The Raven's Message",
            "The Raven's Quill",
            "The Red Slippers",
            "The Revelation",
            "The Ring of Life",
            "The Risen Phoenix",
            "The Royal Frog",
            "The Rune",
            "The Second Chance",
            "The Shooting Star",
            "The Silver Bullet",
            "The Silver Spoon",
            "The Siphon",
            "The Siren's Song",
            "The Skeleton Closet",
            "The Sleeping Owl",
            "The Sleight of Hand",
            "The Soothsayer",
            "The Sorcerer's Source",
            "The Soul Apothecary",
            "The Soulstone",
            "The Spell Counter",
            "The Sphere",
            "The Spirit Walk",
            "The Stone in the Sword",
            "The Summoned Goods",
            "The Summoning Scroll",
            "The Sword in the Stone",
            "The Talisman",
            "The Tenth Ring",
            "The Third Wish",
            "The Time Warp",
            "The Tinkered Tiara",
            "The Trick Sleeve",
            "The Twilight Zone",
            "The Twinkle Star",
            "The Twisting Nether",
            "The Unicorn",
            "The Unicorn's Horn",
            "The Vision",
            "The Voodoo Doll",
            "The Wand's Want",
            "The Water Elemental",
            "The White Beard",
            "The White Dove",
            "The Wishbone",
            "The Witch's Nose",
            "The Wooden Stake",
            "The Wyrm and the Worm",
            "Tinctures 'n Tonics",
            "Tomes and Tiaras",
            "Trident Trinity",
            "Trinkets and Tronkets",
            "Triton's Tident",
            "Wizard's Mail",
        ]
        p2 = [
            "Adorable",
            "Affordable",
            "Aggressive",
            "Amazing",
            "Amusing",
            "Ancient",
            "Angry",
            "Antique",
            "Awesome",
            "Awkward",
            "Baby",
            "Bathing",
            "Big",
            "Bigger",
            "Bitter",
            "Ebon",
            "Bleeding",
            "Blind",
            "Blushing",
            "Brass",
            "Bright",
            "Brilliant",
            "Bronze",
            "Brown",
            "Cheap",
            "Cheating",
            "Cheering",
            "Clean",
            "Clever",
            "Common",
            "Corrupt",
            "Corrupted",
            "Crafty",
            "Crazy",
            "Creeping",
            "Cuddly",
            "Curly",
            "Dancing",
            "Dapper",
            "Dark",
            "Dirty",
            "Dizzy",
            "Dreaming",
            "Eager",
            "Early",
            "Elder",
            "Elegant",
            "Elementary",
            "Evil",
            "Exalted",
            "Expert",
            "Fading",
            "Fair",
            "Fake",
            "False",
            "Famous",
            "Fancy",
            "Fantastic",
            "Fast",
            "Flimsy",
            "Fluffy",
            "Forsaken",
            "Frozen",
            "Gentle",
            "Glass",
            "Glowing",
            "Golden",
            "Graceful",
            "Greedy",
            "Green",
            "Grim",
            "Grumpy",
            "Hairy",
            "Happy",
            "Haunting",
            "Heavy",
            "Hidden",
            "Huge",
            "Humble",
            "Hungry",
            "Invincible",
            "Invisible",
            "Iron",
            "Jolly",
            "Kind",
            "Large",
            "Last",
            "Laughing",
            "Lazy",
            "Light",
            "Little",
            "Lonely",
            "Loving",
            "Lucky",
            "Mad",
            "Majestic",
            "Mellow",
            "Merry",
            "Naughty",
            "Needy",
            "New",
            "Nutty",
            "Old",
            "Phony",
            "Plain",
            "Pretty",
            "Quick",
            "Quiet",
            "Rapid",
            "Rare",
            "Royal",
            "Scary",
            "Screaming",
            "Second",
            "Secret",
            "Serene",
            "Shady",
            "Silly",
            "Silver",
            "Sleeping",
            "Small",
            "Sneaky",
            "Steel",
            "Storm",
            "Striped",
            "Tall",
            "Thunder",
            "Tiny",
            "Tired",
            "Weeping",
            "Wicked",
            "Wild",
            "Wise",
        ]
        p3 = [
            "Amulet",
            "Angel",
            "Artifact",
            "Banshee",
            "Basilisk",
            "Beacon",
            "Bigfoot",
            "Blade",
            "Book",
            "Boots",
            "Branch",
            "Bunyip",
            "Cauldron",
            "Centaur",
            "Cerberus",
            "Chimera",
            "Chupacabra",
            "Cloak",
            "Cockatrice",
            "Codex",
            "Crown",
            "Cupid",
            "Cyclops",
            "Demon",
            "Dragon",
            "Draugr",
            "Dryad",
            "Dwarf",
            "Elemental",
            "Elf",
            "Ent",
            "Fairy",
            "Faun",
            "Feathered Serpent",
            "Focus",
            "Gargoyle",
            "Gauntlet",
            "Genie",
            "Ghost",
            "Giant",
            "Gnome",
            "Gorgon (Medussa)",
            "Gremlin",
            "Griffin",
            "Grim Reaper",
            "Hag",
            "Harpy",
            "Hellhound",
            "Hippocampus",
            "Hippogriff",
            "Hobbit",
            "Hobgoblin",
            "Hourglass",
            "Human",
            "Hydra",
            "Imp",
            "Incubus/Succubus",
            "Jackalope",
            "Key",
            "Kobold",
            "Kraken",
            "Leprechaun",
            "Lich",
            "Lute",
            "Manticore",
            "Marker",
            "Mermaid",
            "Minotaur",
            "Mummy",
            "Naga",
            "Nymph",
            "Ogre",
            "Orb",
            "Pegasus",
            "Phoenix",
            "Pixie",
            "Poltergeist",
            "Quill",
            "Ring",
            "Robe",
            "Roc",
            "Rune",
            "Sandman",
            "Sasquatch",
            "Satyr",
            "Scepter",
            "Scroll",
            "Seal",
            "Shapeshifter",
            "Shield",
            "Siren",
            "Skeleton",
            "Skull",
            "Sphere",
            "Sphinx",
            "Spriggan",
            "Sprite",
            "Staff",
            "Stone",
            "Sword",
            "Talisman",
            "Tiara",
            "Tome",
            "Troll",
            "Unicorn",
            "Valkyrie",
            "Vampire",
            "Vial",
            "Wand",
            "Wendigo",
            "Werecat",
            "Werewolf",
            "White Stag",
            "Winged Lion",
            "Winged Unicorn",
            "Wisp",
            "Wolpertinger",
            "World Turtle",
            "Wraith",
            "Wyvern",
            "Yeti",
            "Zombie",
        ]
        if randrange(2):
            return choice(p1).title()
        else:
            return str("The " + choice(p2) + " " + choice(p3)).title()


class Restaurant(Store):
    class RestaurantType(StrEnum):
        Diner = auto()
        French = auto()
        Tavern = auto()

    @staticmethod
    def Tavern():
        t1 = [
            "The Abandoned",
            "The Absent",
            "The Abstract",
            "The Accidental",
            "The Adorable",
            "The Aggressive",
            "The Alien",
            "The American",
            "The Amused",
            "The Ancient",
            "The Annoying",
            "The Anxious",
            "The Aquatic",
            "The Armed",
            "The Aromatic",
            "The Ashamed",
            "The Asian",
            "The Assorted",
            "The Attractive",
            "The Australian",
            "The Automatic",
            "The Awesome",
            "The Awful",
            "The Bad",
            "The Beautiful",
            "The Best",
            "The Better",
            "The Big",
            "The Bitter",
            "The Bizarre",
            "The Black",
            "The Bloody",
            "The Blue",
            "The Blushing",
            "The Boiling",
            "The Bored",
            "The Bouncy",
            "The Brass",
            "The Brave",
            "The Broad",
            "The Broken",
            "The Bronze",
            "The Bumpy",
            "The Busy",
            "The Calm",
            "The Careful",
            "The Careless",
            "The Cheap",
            "The Chilly",
            "The Chinese",
            "The Chubby",
            "The Chunky",
            "The Clean",
            "The Clever",
            "The Closed",
            "The Clumsy",
            "The Cold",
            "The Colossal",
            "The Confident",
            "The Cool",
            "The Copper",
            "The Courageous",
            "The Cowardly",
            "The Crazy",
            "The Creepy",
            "The Crowded",
            "The Cruel",
            "The Cunning",
            "The Curious",
            "The Cute",
            "The Daily",
            "The Dancing",
            "The Dangerous",
            "The Dapper",
            "The Dark",
            "The Dazzling",
            "The Dead",
            "The Deep",
            "The Defeated",
            "The Defiant",
            "The Delirious",
            "The Deranged",
            "The Deserted",
            "The Detailed",
            "The Devilish",
            "The Diamond",
            "The Different",
            "The Dire",
            "The Dirty",
            "The Disarmed",
            "The Discreet",
            "The Double",
            "The Drab",
            "The Dramatic",
            "The Drunk",
            "The Drunken",
            "The Dry",
            "The Dusty",
            "The Dutch",
            "The Dwarven",
            "The Dwarvish",
            "The Dynamic",
            "The Eager",
            "The Early",
            "The Earthy",
            "The Educated",
            "The Efficient",
            "The Electric",
            "The Elegent",
            "The Elite",
            "The Embarrassed",
            "The Empty",
            "The Enchanted",
            "The Entertaining",
            "The Equal",
            "The Ethereal",
            "The Even",
            "The Excellent",
            "The Excited",
            "The Exclusive",
            "The Exotic",
            "The Expensive",
            "The Fabulous",
            "The Faded",
            "The Faint",
            "The False",
            "The Familiar",
            "The Famous",
            "The Fancy",
            "The Fantastic",
            "The Far",
            "The Far Away",
            "The Fascinated",
            "The Fascinating",
            "The Fast",
            "The Fearless",
            "The Fiery",
            "The Filthy",
            "The Fine",
            "The First",
            "The Fixed",
            "The Flashy",
            "The Fluffy",
            "The Foamy",
            "The Foolish",
            "The Fragile",
            "The Free",
            "The Freezing",
            "The French",
            "The Frightened",
            "The Frightening",
            "The Frozen",
            "The Full",
            "The Future",
            "The Futuristic",
            "The Fuzy",
            "The General",
            "The Gentle",
            "The German",
            "The Ghastly",
            "The Ghost",
            "The Giant",
            "The Gifted",
            "The Gigantic",
            "The Glamorous",
            "The Glistening",
            "The Glorious",
            "The Godly",
            "The Golden",
            "The Good",
            "The Goofy",
            "The Gorgeous",
            "The Grateful",
            "The Gray",
            "The Greasy",
            "The Green",
            "The Grey",
            "The Groovy",
            "The Gruesome",
            "The Grumpy",
            "The Gullible",
            "The Handy",
            "The Happy",
            "The Harsh",
            "The Healthy",
            "The Heavenly",
            "The Heavy",
            "The Hidden",
            "The High",
            "The Hilarious",
            "The Hissing",
            "The Hollow",
            "The Honorable",
            "The Hot",
            "The Huge",
            "The Hungry",
            "The Hypnotic",
            "The Icky",
            "The Imaginary",
            "The Imperfect",
            "The Impolite",
            "The Impossible",
            "The Incompetent",
            "The Incredible",
            "The Infamous",
            "The Innocent",
            "The Intelligent",
            "The Interesting",
            "The International",
            "The Iron",
            "The Itchy",
            "The Ivory",
            "The Jaded",
            "The Jagged",
            "The Japanese",
            "The Jazzy",
            "The Jealous",
            "The Jewish",
            "The Jolly",
            "The Juicy",
            "The Kaput",
            "The Keen",
            "The Kind",
            "The Known",
            "The Lame",
            "The Last",
            "The Late",
            "The Latin",
            "The Latino",
            "The Laughable",
            "The Laughing",
            "The Lazy",
            "The Lean",
            "The Left",
            "The Lethal",
            "The Light",
            "The Likeable",
            "The Limping",
            "The Little",
            "The Lively",
            "The Lonely",
            "The Long",
            "The Longing",
            "The Loud",
            "The Lovely",
            "The Loving",
            "The Lucky",
            "The Lush",
            "The Lying",
            "The Lyrical",
            "The Macho",
            "The Magenta",
            "The Magical",
            "The Magnificent",
            "The Majestic",
            "The Mammoth",
            "The Maniacal",
            "The Marked",
            "The Married",
            "The Marvelous",
            "The Massive",
            "The Mature",
            "The Mean",
            "The Measly",
            "The Mellow",
            "The Melting",
            "The Merciful",
            "The Messy",
            "The Metal",
            "The Middle",
            "The Mighty",
            "The Minor",
            "The Misty",
            "The Mixed",
            "The Mixing",
            "The Modern",
            "The Moldy",
            "The Molten",
            "The Murky",
            "The Mushy",
            "The Mute",
            "The Mysterious",
            "The Naive",
            "The Narrow",
            "The Nasty",
            "The National",
            "The Natural",
            "The Naughty",
            "The Needy",
            "The Nervous",
            "The New",
            "The Next",
            "The Next Best",
            "The Nice",
            "The Nifty",
            "The Nimble",
            "The Nonstalgic",
            "The Obedient",
            "The Obnoxious",
            "The Oceanic",
            "The Odd",
            "The Old",
            "The Old Fashioned",
            "The Open",
            "The Opposite",
            "The Orange",
            "The Organic",
            "The Oriental",
            "The Outrageous",
            "The Overrated",
            "The Painful",
            "The Panoramic",
            "The Parallel",
            "The Pathetic",
            "The Peaceful",
            "The Perfect",
            "The Pink",
            "The Plain",
            "The Pleasant",
            "The Pointless",
            "The Polite",
            "The Poor",
            "The Precious",
            "The Private",
            "The Protective",
            "The Proud",
            "The Psychotic",
            "The Puny",
            "The Purple",
            "The Puzzled",
            "The Puzzling",
            "The Quack",
            "The Quacking",
            "The Quaint",
            "The Quick",
            "The Quickest",
            "The Quiet",
            "The Rabid",
            "The Rainy",
            "The Rapid",
            "The Rare",
            "The Real",
            "The Rebel",
            "The Rebelious",
            "The Red",
            "The Reflecting",
            "The Regular",
            "The Relieved",
            "The Repulsive",
            "The Responsible",
            "The Rich",
            "The Right",
            "The Righteous",
            "The Romantic",
            "The Rotten",
            "The Round",
            "The Royal",
            "The Running",
            "The Russian",
            "The Ruthless",
            "The Sad",
            "The Safe",
            "The Salty",
            "The Scared",
            "The Scary",
            "The Scattered",
            "The Second",
            "The Secret",
            "The Serious",
            "The Shaggy",
            "The Shaking",
            "The Shattered",
            "The Short",
            "The Shouting",
            "The Sick",
            "The Sickly",
            "The Silent",
            "The Silver",
            "The Simple",
            "The Singing",
            "The Skilled",
            "The Skillful",
            "The Skinny",
            "The Sleeping",
            "The Sleepy",
            "The Slippery",
            "The Slow",
            "The Smart",
            "The Smelly",
            "The Smiling",
            "The Smooth",
            "The Snobbish",
            "The Snoring",
            "The Soft",
            "The Solid",
            "The Sore",
            "The Sour",
            "The Sparkling",
            "The Special",
            "The Spectacular",
            "The Spicy",
            "The Spiritual",
            "The Spooky",
            "The Spotless",
            "The Spotted",
            "The Square",
            "The Stately",
            "The Steel",
            "The Stormy",
            "The Successful",
            "The Sudden",
            "The Super",
            "The Superb",
            "The Supreme",
            "The Sweet",
            "The Sweet and Sour",
            "The Swift",
            "The Tacky",
            "The Talented",
            "The Tall",
            "The Tame",
            "The Tasty",
            "The Teeny",
            "The Temporary",
            "The Terrible",
            "The Terrific",
            "The Thanked",
            "The Thankful",
            "The Thick",
            "The Thin",
            "The Third",
            "The Thoughtful",
            "The Threatened",
            "The Threatening",
            "The Thundering",
            "The Timid",
            "The Tiny",
            "The Tipsy",
            "The Tired",
            "The Towering",
            "The Triangular",
            "The Tricky",
            "The Twelve",
            "The Twin",
            "The Typical",
            "The Ugliest",
            "The Ugly",
            "The Unarmed",
            "The Uneven",
            "The Unique",
            "The Unknown",
            "The Unnatural",
            "The Unusual",
            "The Unwritten",
            "The Upset",
            "The Vagabond",
            "The Vague",
            "The Valuable",
            "The Vengeful",
            "The Venomous",
            "The Victorious",
            "The Violent",
            "The Violet",
            "The Voiceless",
            "The Vulgar",
            "The Wacky",
            "The Waiting",
            "The Wandering",
            "The Warm",
            "The Weak",
            "The Well-Groomed",
            "The Wet",
            "The Whimsical",
            "The Whispering",
            "The White",
            "The Wicked",
            "The Wild",
            "The Windy",
            "The Wise",
            "The Wooden",
            "The Worthless",
            "The Wretched",
            "The Wrong",
            "The Demon",
            "The Yellow",
            "The Young",
            "The Zealous",
            "Ye Olde",
            "Ye Olde",
            "Ye Olde",
            "Ye Olde",
            "Ye Olde",
            "Ye Olde",
            "Ye Olde",
            "Ye Olde",
            "Ye Olde",
            "Ye Olde",
        ]
        t2 = [
            "",
            "",
            "",
            "",
            "",
            "",
            "Accordion",
            "Adventurer",
            "Albatross",
            "Alligator",
            "Anemone",
            "Angel",
            "Angels",
            "Ant",
            "Anteater",
            "Antelope",
            "Ants",
            "Ape",
            "Apple",
            "Apples",
            "Arm",
            "Armadillo",
            "Avocado",
            "Axe",
            "Baboon",
            "Bachelor",
            "Badger",
            "Bagpipe",
            "Baker",
            "Balloon",
            "Bamboo",
            "Banjo",
            "Barracuda",
            "Barrel",
            "Barricade",
            "Bass",
            "Bassoon",
            "Bat",
            "Bats",
            "Battleaxe",
            "Bean",
            "Bear",
            "Beard",
            "Bears",
            "Beaver",
            "Beavers",
            "Bed",
            "Bee",
            "Bees",
            "Bell",
            "Bells",
            "Belltower",
            "Bird",
            "Birds",
            "Bison",
            "Blossom",
            "Boat",
            "Bone",
            "Bongo",
            "Book",
            "Books",
            "Boulder",
            "Bow",
            "Bowl",
            "Brain",
            "Branch",
            "Buffalo",
            "Bunny",
            "Butcher",
            "Butterflies",
            "Butterfly",
            "Cabbage",
            "Cake",
            "Camel",
            "Canary",
            "Candle",
            "Captain",
            "Carrot",
            "Cashew",
            "Castle",
            "Cat",
            "Caterpillar",
            "Cats",
            "Cave",
            "Cavern",
            "Celery",
            "Cello",
            "Chain",
            "Chainmail",
            "Chair",
            "Cheese",
            "Cheetah",
            "Cherry",
            "Chestnut",
            "Chestplate",
            "Chick",
            "Chicken",
            "Child",
            "Chimpanzee",
            "Cinamon",
            "City",
            "Clam",
            "Clams",
            "Clarinet",
            "Cliff",
            "Cloth",
            "Cobra",
            "Coconut",
            "Cod",
            "Coin",
            "Cookie",
            "Corn",
            "Couple",
            "Coyote",
            "Crab",
            "Crabs",
            "Crane",
            "Crew",
            "Crocodile",
            "Crossbow",
            "Crow",
            "Crows",
            "Crystal",
            "Cucumber",
            "Cup",
            "Curry",
            "Cushion",
            "Dagger",
            "Dahlia",
            "Dandelion",
            "Dark Elf",
            "Dawg",
            "Deer",
            "Demon",
            "Demons",
            "Desk",
            "Dessert",
            "Didgeridoo",
            "Dinosaur",
            "Discovery",
            "Dog",
            "Dogs",
            "Donkey",
            "Dove",
            "Doves",
            "Dragon",
            "Dragonfruit",
            "Dragons",
            "Drum",
            "Drumstick",
            "Duck",
            "Ducks",
            "Duduk",
            "Dwarf",
            "Eagle",
            "Eagles",
            "Eel",
            "Egg",
            "Elderberry",
            "Elephant",
            "Elephant Seal",
            "Elephants",
            "Elf",
            "Emu",
            "Explorer",
            "Fairy",
            "Falcon",
            "Falcons",
            "Ferret",
            "Fiddle",
            "Fiddler",
            "Fig",
            "Fire",
            "Fish",
            "Flame",
            "Flea",
            "Flies",
            "Flower",
            "Flute",
            "Fly",
            "Forest",
            "Fork",
            "Fowl",
            "Fox",
            "Frog",
            "Gang",
            "Garden",
            "Gate",
            "Gauntlet",
            "Gazelle",
            "Geese",
            "Gentleman",
            "Gentlemen",
            "Gentlewoman",
            "Gentlewomen",
            "Giant",
            "Giraffe",
            "Glass",
            "Glory",
            "Goat",
            "Goats",
            "Goose",
            "Gooseberry",
            "Gopher",
            "Gorilla",
            "Grape",
            "Grasshopper",
            "Grotto",
            "Group",
            "Guard",
            "Guinea Pig",
            "Guinea Pigs",
            "Guitar",
            "Hag",
            "Halberd",
            "Hammer",
            "Hamster",
            "Hamsters",
            "Hand",
            "Harbour",
            "Harp",
            "Hatchet",
            "Hawk",
            "Hawks",
            "Hazelnut",
            "Head",
            "Heart",
            "Helm",
            "Helmet",
            "Hill",
            "Hippo",
            "Hippopotamus",
            "Hog",
            "Horn",
            "Hornet",
            "Hornets",
            "Horse",
            "Horses",
            "Hunter",
            "Huntress",
            "Husband",
            "Hyacinth",
            "Hyena",
            "Ice",
            "Ingot",
            "Jackal",
            "Jackals",
            "Jaguar",
            "Jellyfish",
            "Jester",
            "Kangaroo",
            "King",
            "Kitten",
            "Kiwi",
            "Knife",
            "Knight",
            "Koala",
            "Kumquat",
            "Lady",
            "Lake",
            "Lamb",
            "Lamp",
            "Lantern",
            "Lavender",
            "Leader",
            "Leaf",
            "Leg",
            "Lemon",
            "Leopard",
            "Lettuce",
            "Librarian",
            "Library",
            "Lily",
            "Lime",
            "Lion",
            "Lioness",
            "Lions",
            "Llama",
            "Loaf",
            "Lobster",
            "Lobsters",
            "Loch",
            "Lord",
            "Lute",
            "Lychee",
            "Lyre",
            "Magpie",
            "Manatee",
            "Mandolin",
            "Mango",
            "Maple",
            "Marigold",
            "Master",
            "Meat",
            "Meerkat",
            "Melon",
            "Melons",
            "Mice",
            "Midget",
            "Mind",
            "Mole",
            "Moon",
            "Morning Glory",
            "Mosquito",
            "Mountain",
            "Mouse",
            "Moustache",
            "Mushroom",
            "Narcissus",
            "Night",
            "Night Elf",
            "Nightingale",
            "Note",
            "Nugget",
            "Nut",
            "Nutmeg",
            "Oak",
            "Ocean",
            "Octopus",
            "Olive",
            "Onion",
            "Opossum",
            "Orange",
            "Orangutan",
            "Orc",
            "Ore",
            "Ostrich",
            "Otter",
            "Owl",
            "Ox",
            "Oyster",
            "Oysters",
            "Palm",
            "Pan Flute",
            "Panda",
            "Panther",
            "Pants",
            "Papaya",
            "Parrot",
            "Parrots",
            "Parsnip",
            "Pea",
            "Peacock",
            "Peanut",
            "Pear",
            "Pearl",
            "Pegasus",
            "Pelican",
            "Peon",
            "Pepper",
            "Piano",
            "Pickaxe",
            "Pie",
            "Pig",
            "Pigeon",
            "Pigeons",
            "Pike",
            "Pillow",
            "Pirate",
            "Pistachio",
            "Planet",
            "Plate",
            "Ponies",
            "Pony",
            "Potato",
            "Prince",
            "Princess",
            "Pudding",
            "Pumpkin",
            "Puppy",
            "Queen",
            "Rabbit",
            "Raccoon",
            "Rapier",
            "Raspberry",
            "Rat",
            "Rats",
            "Raven",
            "Reindeer",
            "Rhino",
            "Rhinoceros",
            "Rhododendron",
            "River",
            "Rock",
            "Root",
            "Rope",
            "Rose",
            "Sail",
            "Sailboat",
            "Salad",
            "Salmon",
            "Salt",
            "Saxophone",
            "Scream",
            "Sea",
            "Seadog",
            "Seagull",
            "Seagulls",
            "Seahorse",
            "Seal",
            "Seals",
            "Serpent",
            "Shark",
            "Sharks",
            "Sheep",
            "Shield",
            "Ship",
            "Shipmate",
            "Shirt",
            "Shoe",
            "Shovel",
            "Shrub",
            "Sign",
            "Skies",
            "Skull",
            "Skunk",
            "Skunks",
            "Snail",
            "Snake",
            "Snakes",
            "Snapdragon",
            "Snow",
            "Snowball",
            "Snowdrop",
            "Snowfall",
            "Soup",
            "Spade",
            "Spider",
            "Spiders",
            "Spoon",
            "Squash",
            "Squid",
            "Squirrel",
            "Stag",
            "Star",
            "Stars",
            "Steed",
            "Stew",
            "Stick",
            "Stone",
            "Strawberry",
            "Stream",
            "Sugar",
            "Sun",
            "Swallow",
            "Swan",
            "Sword",
            "Table",
            "Tankard",
            "Tauren",
            "Tea Cup",
            "Termite",
            "Throne",
            "Tiger",
            "Tigers",
            "Tigress",
            "Toad",
            "Tomato",
            "Tortoise",
            "Tower",
            "Town",
            "Traveler",
            "Tree",
            "Trespasser",
            "Triangle",
            "Troll",
            "Trombone",
            "Trout",
            "Truffle",
            "Trumpet",
            "Trunk",
            "Tuba",
            "Tulip",
            "Turkey",
            "Turnip",
            "Turtle",
            "Tusk",
            "Twig",
            "Ukulele",
            "Unicorn",
            "Unicorns",
            "Vampire",
            "Vanilla",
            "Vanilla Bean",
            "Violin",
            "Wall",
            "Water",
            "Weasel",
            "Well",
            "Whale",
            "Whip",
            "Whisper",
            "Whistle",
            "Wife",
            "Wilderbeast",
            "Willow",
            "Wolf",
            "Wolves",
            "Wood Elf",
            "Woodpecker",
            "Worker",
            "Worm",
            "Xylophone",
            "Yak",
            "Yam",
            "Yew",
            "Zebra",
        ]
        t3 = ["Pub", "Tavern", "Inn", "Bar", "", ""]
        return choice(t1) + " " + choice(t2) + " " + choice(t3)

    @staticmethod
    def Diner():
        r1 = [
            "Abacus",
            "Amber",
            "Aqua",
            "Arctic",
            "Aroma",
            "Autumn",
            "Baking",
            "Bamboo",
            "Beach",
            "Bengal",
            "Big",
            "Big City",
            "Bitter",
            "Boiling",
            "Bright",
            "Saffron",
            "Brimstone",
            "Bronze",
            "Caramel",
            "Caribbean",
            "Caviar",
            "Central",
            "Champagne",
            "Charming",
            "Chili",
            "Chocolate",
            "Chopping",
            "Cinnamon",
            "City",
            "Clear",
            "Coastal",
            "Cocoa",
            "Coffee",
            "Comet",
            "Cool",
            "Cool Cat",
            "Copper",
            "Coriander",
            "Corner",
            "Court",
            "Crimson",
            "Crystal",
            "Curry",
            "Dairy",
            "Dapper",
            "Delhi",
            "Dwarf",
            "Eastern",
            "Electric",
            "Emerald",
            "Enigma",
            "Fable",
            "Fantasy",
            "Fiery",
            "Fire",
            "First",
            "Forest",
            "French",
            "Fresh",
            "Friendly",
            "Gallery",
            "Glass",
            "Golden",
            "Grand",
            "Greek",
            "Harborview",
            "Harlequin",
            "Harmonic",
            "Holy",
            "Honey",
            "Honor",
            "Hot",
            "Hungry",
            "Imperial",
            "Incredible",
            "Indian",
            "Island",
            "Italian",
            "Jade",
            "Jamming",
            "Japanese",
            "Jazz",
            "Jungle",
            "Juniper",
            "Karma",
            "King's",
            "Lakeside",
            "Lavender",
            "Light",
            "Little",
            "Lunar",
            "Mad",
            "Magical",
            "Malt",
            "Mammoth",
            "Meadow",
            "Mellow",
            "Minty",
            "Modern",
            "Moroccan",
            "Mountain",
            "Mountainview",
            "Narrow",
            "New",
            "Nifty",
            "Noodle",
            "Northern",
            "Old",
            "Olive",
            "Orange",
            "Original",
            "Oval",
            "Painted",
            "Palm",
            "Paradise",
            "Pearl",
            "Pepper",
            "Pink",
            "Polar",
            "Private",
            "Proud",
            "Queen's",
            "Rare",
            "River",
            "Royal",
            "Ruby",
            "Sailing",
            "Salty",
            "Sapphire",
            "Savory",
            "Seaside",
            "Shining",
            "Silent",
            "Silk",
            "Silver",
            "Solar",
            "Sour",
            "Southern",
            "Spaghetti",
            "Spiced",
            "Spicy",
            "Spring",
            "Square",
            "Streetwise",
            "Sugar",
            "Summer",
            "Sumo",
            "Sushi",
            "Sweet",
            "Tandoori",
            "Thai",
            "Tropical",
            "Underwater",
            "Urban",
            "Vanilla",
            "Village",
            "Vintage",
            "Violet",
            "Warm",
            "Waterfront",
            "Waterway",
            "Western",
            "Whiskey",
            "Wild",
            "Winter",
        ]
        r2 = [
            "After Dark",
            "Afternoon",
            "Ambience",
            "Angel",
            "Apple",
            "Archive",
            "Avenue",
            "Badger",
            "Balcony",
            "Barbecue",
            "Bass",
            "Bay",
            "Bear",
            "Beehive",
            "Bistro",
            "Bite",
            "Bites",
            "Blanket",
            "Blend",
            "Block",
            "Blossom",
            "Boar",
            "Bond",
            "Boulevard",
            "Brewery",
            "Brothers",
            "Canteen",
            "Castle",
            "Catch",
            "Chamber",
            "Chef",
            "Chicken",
            "Chimney",
            "Clam",
            "Cloud",
            "Clove",
            "Club",
            "Commander",
            "Cottage",
            "Court",
            "Courtyard",
            "Cow",
            "Crown",
            "Cuisine",
            "Dairy",
            "Deer",
            "Demon",
            "Devil",
            "Diner",
            "Docks",
            "Dome",
            "Door",
            "Dragon",
            "Dream",
            "Drum",
            "Duke",
            "Eats",
            "Elephant",
            "Emperor",
            "Empress",
            "Exchange",
            "Exhibit",
            "Fable",
            "Factory",
            "Faire",
            "Farmer",
            "Fence",
            "Fiddler",
            "Fish",
            "Flavour",
            "Flower",
            "Fox",
            "Fridge",
            "Front",
            "Fusion",
            "Garden",
            "Gate",
            "Genie",
            "Goat",
            "God",
            "Goddess",
            "Grill",
            "Grove",
            "Harvest",
            "Heart",
            "Heaven",
            "Hog",
            "Hook",
            "Horse",
            "Hound",
            "House",
            "Jewel",
            "Junction",
            "Kitchen",
            "Knight",
            "Laguna",
            "Lane",
            "Lantern",
            "Leaf",
            "Lighthouse",
            "Lily",
            "Lion",
            "Lobster",
            "Lounge",
            "Maple",
            "Market",
            "Merchant",
            "Mirror",
            "Mission",
            "Mockingbird",
            "Moment",
            "Moments",
            "Monkey",
            "Monument",
            "Morning",
            "Night",
            "Nights",
            "Oak",
            "Orchard",
            "Orchid",
            "Oriental",
            "Oyster",
            "Palace",
            "Panda",
            "Pantry",
            "Paradise",
            "Parlour",
            "Peasant",
            "Persia",
            "Petal",
            "Pig",
            "Pipe",
            "Pizzeria",
            "Place",
            "Pond",
            "Port",
            "Ranch",
            "Road",
            "Rooftop",
            "Room",
            "Rose",
            "Salmon",
            "Saloon",
            "Scarf",
            "Shack",
            "Shark",
            "Ship",
            "Shrimp",
            "Sisters",
            "Smith",
            "Spice",
            "Spices",
            "Star",
            "Stranger",
            "Street",
            "Street Kitchen",
            "Table",
            "Taste",
            "Tiger",
            "Tower",
            "Tree",
            "Trumpet",
            "Tulip",
            "Valley",
            "Vaults",
            "Victory",
            "View",
            "Vine",
            "Violin",
            "Walk",
            "Way",
            "Well",
            "Whale",
            "Wharf",
            "Willow",
            "Windmill",
            "Window",
            "Wok",
            "Word",
            "Yard",
        ]
        r3 = [
            "Abacus",
            "Acapella",
            "Ace",
            "After Dark",
            "Alpha",
            "Ambience",
            "Amigos",
            "Amuse",
            "Aqua",
            "Arch",
            "Aroma",
            "Atlas",
            "Aurora",
            "Babylon",
            "Backstage",
            "Bambino",
            "Bandits",
            "Basil",
            "Beehive",
            "Blossoms",
            "Blueprint",
            "Bonds",
            "Bones",
            "Bounty",
            "Brimstone",
            "Butlers",
            "Buttons",
            "Candle",
            "Carnival",
            "Castle",
            "Catch",
            "Chance",
            "Chapter",
            "Charm",
            "Cinnamon",
            "Citrus",
            "Clarity",
            "Cocoa",
            "Crickets",
            "Curiosity",
            "Daydream",
            "Drifters",
            "Elementary",
            "Elements",
            "Embers",
            "Enigma",
            "Eureka",
            "Fabled",
            "Fantasia",
            "Fiddler",
            "Fire and Ice",
            "Fluorescence",
            "Forester",
            "Friends",
            "Gastrognome",
            "Gem",
            "Gentle",
            "Glasshouse",
            "Grace",
            "Happening",
            "Harlequin",
            "Harmony",
            "Harvest",
            "Hibiscus",
            "Incognito",
            "Indigo",
            "Interlude",
            "Intermezzo",
            "Intermission",
            "Ivory",
            "Ivy",
            "Jewel",
            "Jubilee",
            "Karma",
            "Kings",
            "Kingsize",
            "Laguna",
            "Lavender",
            "Lemon",
            "Lemon Grass",
            "Lily",
            "Limestone",
            "Little China",
            "Little Italy",
            "Little Persia",
            "Maximus",
            "Maze",
            "Meadows",
            "Medallion",
            "Melting Pot",
            "Midnight",
            "Mirage",
            "Mirrors",
            "Modesty",
            "Moonlight",
            "Mumbles",
            "Nightowl",
            "Nirvana",
            "Nova",
            "Oddity",
            "Olive Grove",
            "Paragon",
            "Paramount",
            "Parlay",
            "Pavilion",
            "Petals",
            "Piccolo",
            "Podium",
            "Potroast",
            "Prospects",
            "Purity",
            "Queens",
            "Recess",
            "Retro",
            "Revelations",
            "Roadhouse",
            "Roast",
            "Robot",
            "Rogue",
            "Roots",
            "Rye",
            "Saffron",
            "Salutation",
            "Sapphire",
            "Seawise",
            "Serenade",
            "Serenity",
            "Shambles",
            "Shazam",
            "Simmer Down",
            "Skyward",
            "Solitude",
            "Solo Mio",
            "Solstice",
            "Souls",
            "Splash",
            "Starlight",
            "Steam",
            "Streetwise",
            "Sunset",
            "The Bell Tower",
            "The Boar",
            "The Boutique",
            "The Cane",
            "The Cave",
            "The Cellar",
            "The Cottage",
            "The Crown",
            "The Depot",
            "The Eclipse",
            "The Emperor",
            "The Empress",
            "The Exhibit",
            "The Gallery",
            "The Garden",
            "The Goat",
            "The Grove",
            "The Hat",
            "The Hive",
            "The Hog",
            "The Hummingbird",
            "The Island",
            "The Lamb",
            "The Lighthouse",
            "The Lion",
            "The Locket",
            "The Lotus",
            "The Maple",
            "The Mockingbird",
            "The Momument",
            "The Monarch",
            "The Nightingale",
            "The Nomad",
            "The Oak",
            "The Parlour",
            "The Peacock",
            "The Pearl",
            "The Rose",
            "The Scarf",
            "The Smile",
            "The Square",
            "The Tower",
            "The Tulip",
            "The Turban",
            "The Vine",
            "The Vineyard",
            "The Wall",
            "The Willow",
            "Tip Top",
            "Tranquility",
            "Treasure",
            "Trilogy",
            "Trinity",
            "Twilight",
            "Unwind",
            "Veil",
            "Vertigo",
            "Vista",
            "Whammy",
            "Whisperwind",
        ]
        if randrange(2):
            return "The " + choice(r1) + " " + choice(r2)
        else:
            return choice(r3)

    @staticmethod
    def French():
        r1 = [
            "Elegant",
            "Emeraude",
            "Epice",
            "Acide",
            "Acidule",
            "Affame",
            "Ambre",
            "Amer",
            "Ancien",
            "Antique",
            "Arctique",
            "Ardent",
            "Argente",
            "Bengale",
            "Bouillant",
            "Brulent",
            "Brillant",
            "Cotier",
            "Carre",
            "Chaleureux",
            "Charmant",
            "Chaud",
            "Chic",
            "Chouette",
            "Clair",
            "Cramoisi",
            "Dore",
            "Doux",
            "Fier",
            "Fou",
            "Frais",
            "Francais",
            "Gracieux",
            "Grec",
            "Harmonique",
            "Incarnat",
            "Incroyable",
            "Indien",
            "Italien",
            "Japonais",
            "Laitier",
            "Lunaire",
            "Magique",
            "Marocain",
            "Moderne",
            "Moelleux",
            "Ovale",
            "Peint",
            "Pimpant",
            "Polaire",
            "Prive",
            "Rare",
            "Releve",
            "Rose",
            "Sacre",
            "Sale",
            "Sauvage",
            "Silencieux",
            "Solaire",
            "Sous-Marin",
            "Soyeux",
            "Suave",
            "Sucre",
            "Sympa",
            "Thailandais",
            "Urbain",
            "Veloute",
            "Violet",
            "d'enigme",
            "d'ete",
            "d'Abaque",
            "d'Ambre",
            "d'Aqua",
            "d'Arome",
            "d'Arlequin",
            "d'Aura",
            "d'Automne",
            "d'Eau",
            "d'Harmonie",
            "d'Hiver",
            "d'Honneur",
            "d'Olive",
            "d'Or",
            "d'Orange",
            "de Bambou",
            "de Bord de la Mer",
            "de Bord du Lac",
            "de Bronze",
            "de Cabotage",
            "de Cacao",
            "de Cafe",
            "de Cannelle",
            "de Caramel",
            "de Caviar",
            "de Champagne",
            "de Chocolat",
            "de Coriandre",
            "de Couperet",
            "de Cramoisi",
            "de Cristal",
            "de Cuibre",
            "de Cuisson",
            "de Fantaisie",
            "de Feu",
            "de Front de Mer",
            "de Genevrier",
            "de Grande Ville",
            "de Jade",
            "de Jazz",
            "de Karma",
            "de Laiterie",
            "de Lavande",
            "de Lumiere",
            "de Malt",
            "de Miel",
            "de Paradis",
            "de Paume",
            "de Perle",
            "de Piments",
            "de Plage",
            "de Poivre",
            "de Printemps",
            "de Rubis",
            "de Safran",
            "de Saphir",
            "de Sarriette",
            "de Soie",
            "de Soufre",
            "de Sushi",
            "de Vanille",
            "de Verre",
            "de Village",
            "de Ville",
            "de Whisky",
            "de l'enigme",
            "de l'Ile",
            "de l'Est",
            "de l'Ouest",
            "de la Comete",
            "de la Cour",
            "de la Fable",
            "de la Flamme",
            "de la Foret",
            "de la Galerie",
            "de la Jungle",
            "de la Legende",
            "de la Montagne",
            "de la Nouille",
            "de la Plage",
            "de la Prairie",
            "de la Reine",
            "de la Riviere",
            "de la Rue",
            "de la Voie Navale",
            "des Caraibes",
            "du Canal",
            "du Coin",
            "du Curry",
            "du Feu",
            "du Fleuve",
            "du Nain",
            "du Nord",
            "du Pre",
            "du Quai",
            "du Roi",
            "du Sucre",
            "du Sud",
            "du Tribunal",
            "du Village",
            "Tropical",
            "Royal",
            "Principal",
            "Oriental",
            "Original",
            "Imperial",
            "Central",
            "Austral",
            "Amical",
        ]
        r2 = [
            "elegante",
            "emeraude",
            "epicee",
            "Acide",
            "Acidulee",
            "Affamee",
            "Ambree",
            "Amere",
            "Ancienne",
            "Antique",
            "Arctique",
            "Ardente",
            "Argentee",
            "Bengale",
            "Bouillante",
            "Brulente",
            "Brillante",
            "Cotiere",
            "Carree",
            "Chaleureuse",
            "Charmante",
            "Chaude",
            "Chic",
            "Chouette",
            "Claire",
            "Cramoisie",
            "Doree",
            "Douce",
            "Fiere",
            "Folle",
            "FraIche",
            "Francaise",
            "Gracieuse",
            "Grecque",
            "Harmonique",
            "Incarnate",
            "Incroyable",
            "Indienne",
            "Italienne",
            "Japonaise",
            "Laitiere",
            "Lunaire",
            "Magique",
            "Marocaine",
            "Moderne",
            "Moelleuse",
            "Ovale",
            "Peinte",
            "Pimpante",
            "Polaire",
            "Privee",
            "Rare",
            "Relevee",
            "Rose",
            "Sacree",
            "Salee",
            "Sauvage",
            "Silencieuce",
            "Solaire",
            "Sous-Marine",
            "Soyeuse",
            "Suave",
            "Sucree",
            "Sympa",
            "Thailandaise",
            "Urbaine",
            "Veloutee",
            "Violette",
            "d'enigme",
            "d'ete",
            "d'Abaque",
            "d'Ambre",
            "d'Aqua",
            "d'Arome",
            "d'Arlequin",
            "d'Aura",
            "d'Automne",
            "d'Eau",
            "d'Harmonie",
            "d'Hiver",
            "d'Honneur",
            "d'Olive",
            "d'Or",
            "d'Orange",
            "de Bambou",
            "de Bord de la Mer",
            "de Bord du Lac",
            "de Bronze",
            "de Cabotage",
            "de Cacao",
            "de Cafe",
            "de Cannelle",
            "de Caramel",
            "de Caviar",
            "de Champagne",
            "de Chocolat",
            "de Coriandre",
            "de Couperet",
            "de Cramoisi",
            "de Cristal",
            "de Cuibre",
            "de Cuisson",
            "de Fantaisie",
            "de Feu",
            "de Front de Mer",
            "de Genevrier",
            "de Grande Ville",
            "de Jade",
            "de Jazz",
            "de Karma",
            "de Laiterie",
            "de Lavande",
            "de Lumiere",
            "de Malt",
            "de Miel",
            "de Paradis",
            "de Paume",
            "de Perle",
            "de Piments",
            "de Plage",
            "de Poivre",
            "de Printemps",
            "de Rubis",
            "de Safran",
            "de Saphir",
            "de Sarriette",
            "de Soie",
            "de Soufre",
            "de Sushi",
            "de Vanille",
            "de Verre",
            "de Village",
            "de Ville",
            "de Whisky",
            "de l'enigme",
            "de l'Ile",
            "de l'Est",
            "de l'Ouest",
            "de la Comete",
            "de la Cour",
            "de la Fable",
            "de la Flamme",
            "de la Foret",
            "de la Galerie",
            "de la Jungle",
            "de la Legende",
            "de la Montagne",
            "de la Nouille",
            "de la Plage",
            "de la Prairie",
            "de la Reine",
            "de la Riviere",
            "de la Rue",
            "de la Voie Navale",
            "des Caraibes",
            "du Canal",
            "du Coin",
            "du Curry",
            "du Feu",
            "du Fleuve",
            "du Nain",
            "du Nord",
            "du Pre",
            "du Quai",
            "du Roi",
            "du Sucre",
            "du Sud",
            "du Tribunal",
            "du Village",
            "Tropicale",
            "Royale",
            "Principale",
            "Orientale",
            "Originale",
            "Imperiale",
            "Centrale",
            "Australe",
            "Amicale",
        ]
        r3 = [
            "l'echarpe",
            "l'epice",
            "l'etoile",
            "l'Ambiance",
            "l'Archive",
            "l'Atmosphere",
            "la Baie",
            "la Balade",
            "la Baleine",
            "la Basse",
            "la Biche",
            "la Brasserie",
            "la Cabane",
            "la Cantine",
            "la Capture",
            "la Chevre",
            "la Chambre",
            "la Cheminee",
            "la Cocotte",
            "la Cour",
            "la Couronne",
            "la Couverture",
            "la Crevette",
            "la Cuisine",
            "la Deesse",
            "la Duchesse",
            "l'Exposition",
            "la Facon",
            "la Fable",
            "la Fenetre",
            "la Ferme",
            "la Feuille",
            "la Fleur",
            "la Floraison",
            "la Fusion",
            "l'HuItre",
            "l'Idole",
            "l'Imperatrice",
            "la Legende",
            "la Lagune",
            "la Lanterne",
            "la Liaison",
            "la Libellule",
            "la Maison",
            "la Mare",
            "la Matinee",
            "la Merveille",
            "la Mission",
            "la Morsure",
            "la Nappe",
            "la Nuit",
            "l'Orchidee",
            "la Paloudre",
            "la Parole",
            "la Perle",
            "la Pizzeria",
            "la Pomme",
            "la Porte",
            "la Poule",
            "la Promenade",
            "la Recolte",
            "la Rose",
            "la Route",
            "la Ruche",
            "la Rue",
            "la Salle",
            "la Saveur",
            "la Soiree",
            "la Source",
            "la Table",
            "la Tour",
            "la Tulipe",
            "l'Usine",
            "la Vache",
            "la Vallee",
            "la Victoire",
            "la Vigne",
            "la Voute",
            "la Voie",
            "la Vue",
            "l'echange",
            "l'elephant",
            "l'erable",
            "l'etalage",
            "l'Ange",
            "l'Apres-Midi",
            "l'Arbre",
            "le Balcon",
            "le Bassin",
            "le Bateau",
            "le Bijou",
            "le Bistro",
            "le Blaireau",
            "le Bloc",
            "le Bosquet",
            "le Boulevard",
            "le Coeur",
            "le Carrefour",
            "le Cavalier",
            "le Cerf",
            "le Chateau",
            "le Chene",
            "le Champ",
            "le Chef",
            "le Chemin",
            "le Cheval",
            "le Chevalier",
            "le Ciel",
            "le Club",
            "le Coin",
            "le Colibri",
            "le Commandant",
            "le Cottage",
            "le Demon",
            "le DIner",
            "le DIneur",
            "le Dome",
            "le Diable",
            "le Dieu",
            "le Dragon",
            "le Duc",
            "l'Empereur",
            "l'Endroit",
            "le Fleur",
            "le Forgeron",
            "le Foulard",
            "le Foyer",
            "le Frigo",
            "le Genie",
            "le Gout",
            "le Gril",
            "le Hall",
            "le Homard",
            "l'Instant",
            "le Jardin",
            "le Lien",
            "le Lieu",
            "le Lion",
            "le Lis",
            "le Loup",
            "le Melange",
            "le Manoir",
            "le Marche",
            "le Matin",
            "le Miroir",
            "le Moisson",
            "le Moment",
            "le Monument",
            "le Morceau",
            "le Mot",
            "le Moulin",
            "le Navire",
            "le Nuage",
            "l'Ours",
            "le Petale",
            "le Palais",
            "le Panda",
            "le Paradis",
            "le Parc",
            "le Parfum",
            "le Parloir",
            "le Paysan",
            "le Perchoir",
            "le Phare",
            "le Piment",
            "le Poisson",
            "le Port",
            "le Quai",
            "le Reve",
            "le Ranch",
            "le Renard",
            "le Requin",
            "le Salon",
            "le Sanglier",
            "le Saule",
            "le Saumon",
            "le Singe",
            "le Sommet",
            "le Tableau",
            "le Tambour",
            "le Theatre",
            "le Tigre",
            "le Toit",
            "le Trefle",
            "le Triomphe",
            "le Vaisseau",
            "le Verger",
            "le Violon",
            "le Violoneux",
            "le Yard",
        ]
        r4 = [
            "elementaire",
            "Acapella",
            "Agrume",
            "Alpha",
            "Ambiance",
            "Aqua",
            "Atlas",
            "Babylone",
            "Bambino",
            "Basilic",
            "Boutons",
            "Cacao",
            "Citronnelle",
            "Clair de Lune",
            "Clarte",
            "Coquin",
            "Coucher du Soleil",
            "Curiosite",
            "Eau",
            "Eureka",
            "Feu et Glace",
            "Fleurs",
            "Floraisons",
            "Fluorescence",
            "Geant",
            "Gentil",
            "Grace",
            "Harmonie",
            "Incognito",
            "Indigo",
            "Legendaire",
            "Lavande",
            "Lueuer des etoiles",
            "Maximus",
            "Merveille",
            "Minuit",
            "Miroirs",
            "Modestie",
            "Nirvana",
            "Nova",
            "Oiseau de Nuit",
            "Petales",
            "Petite Chine",
            "Petite Italie",
            "Petite Perse",
            "Piccolo",
            "Primordial",
            "Purete",
            "Recreation",
            "Retro",
            "Revelations",
            "Reveries",
            "Reines",
            "Royal",
            "Seduction",
            "Serenite",
            "Safran",
            "Seigle",
            "Shazam",
            "Solitude",
            "Tranquillite",
            "Vagabonds",
            "Vers le Ciel",
            "Violoneux",
            "des Os",
            "l'eclipse",
            "l'enigme",
            "l'erable",
            "l'etalage",
            "l'evenement",
            "l'Ile",
            "l'Abaque",
            "l'Accord",
            "l'Ace",
            "l'Agneau",
            "l'Amusement",
            "l'Arome",
            "l'Arche",
            "l'Arlequin",
            "l'Atmosphere",
            "l'Aura",
            "l'Aurore",
            "l'Empereur",
            "l'Entracte",
            "l'Exposition",
            "l'Hibiscus",
            "l'Imperatrice",
            "l'Interlude",
            "l'Intermezzo",
            "l'Intermission",
            "l'Interruption",
            "l'Ivoire",
            "l'Occasion",
            "l'Oiseau Moqueur",
            "l'Oliveraie",
            "l'Origine",
            "la Base.py",
            "la Bougie",
            "la Boutique",
            "la Braise",
            "la Branche",
            "la Brume",
            "la Canne",
            "la Cannelle",
            "la Capture",
            "la Cave",
            "la Caverne",
            "la Chevre",
            "la Chance",
            "la Chandelle",
            "la Cime",
            "la Couronne",
            "la Curiosite",
            "la Fable",
            "la Fantaisie",
            "la Fusion",
            "la Galerie",
            "la Gemme",
            "la Goutte",
            "la Grotte",
            "la Joliesse",
            "la Legende",
            "la Lagune",
            "la Liaison",
            "la Lumiere des etoiles",
            "la Muraille",
            "la Niche",
            "la Nuit",
            "la Nuit Tombee",
            "la Penombre",
            "la Pagaille",
            "la Pause",
            "la Perle",
            "la Perspective",
            "la Petite Maison",
            "la Prairie",
            "la Prime",
            "la Recolte",
            "la Reverie",
            "la Rose",
            "la Ruche",
            "la Serenade",
            "la Salutation",
            "la Sensation",
            "la Serre",
            "la Singularite",
            "la Tour",
            "la Tribune",
            "la Trilogie",
            "la Trinite",
            "la Tulipe",
            "la Verrerie",
            "la Vieillesse",
            "la Vigne",
            "la Voute",
            "la Vue",
            "le Bosquet",
            "le Calcaire",
            "le Calme",
            "le Carnaval",
            "le Chateau",
            "le Chapeau",
            "le Chapitre",
            "le Charme",
            "le Clocher",
            "le Colibri",
            "le Cottage",
            "le Couloir",
            "le Crane",
            "le Crepuscule",
            "le Creuset",
            "le Depot",
            "le Forestier",
            "le GastroGnome",
            "le Gastronome",
            "le Grillage",
            "le Jardin",
            "le Jubile",
            "le Karma",
            "le Labyrinthe",
            "le Lien",
            "le Lierre",
            "le Lion",
            "le Lis",
            "le Lotus",
            "le Medaillon",
            "le Marmonnement",
            "le Mirage",
            "le Monarque",
            "le Monument",
            "le Mur",
            "le Nomade",
            "le Paon",
            "le Parangon",
            "le Parloir",
            "le Pavillon",
            "le Plan",
            "le Podium",
            "le Pre",
            "le Projet",
            "le Roti",
            "le Recoin",
            "le Relais",
            "le Robot",
            "le Rossignol",
            "le Sanglier",
            "le Saphir",
            "le Saule",
            "le Solstice",
            "le Sommet",
            "le Sortilege",
            "le Soufre",
            "le Sourire",
            "le Sous-Sol",
            "le Tresor",
            "le Turban",
            "le Vignoble",
            "le Voile",
            "les ames",
            "les elements",
            "les Amis",
            "les Bandits",
            "les Grillons",
            "les Prairies",
            "les Rois",
        ]
        r = randrange(3)
        if r == 0:
            return choice(r3) + " " + choice(r1)
        elif r == 1:
            return choice(r3) + " " + choice(r2)
        else:
            return choice(r4)

    @staticmethod
    def generate(classification=None):
        if classification is None or classification not in Restaurant.RestaurantType:
            classification = choice(list(Restaurant.RestaurantType))
        if classification == Restaurant.RestaurantType.Diner:
            return Restaurant.Diner()
        elif classification == Restaurant.RestaurantType.French:
            return Restaurant.French()
        elif classification == Restaurant.RestaurantType.Tavern:
            return Restaurant.Tavern()


class Jeweller(Store):
    @staticmethod
    def generate():
        j1 = [
            "A Hill of Beads",
            "A Sparkly Thing",
            "A Strand Above",
            "A Strand For You",
            "Accustomed",
            "Adornmix",
            "Around the Block",
            "Artik",
            "Artsifi",
            "Be Adorned",
            "Bead Adorned",
            "Bead Alternique",
            "Bead Assemblage",
            "Bead Chic",
            "Bead It Again",
            "Beaded Creations",
            "Beadiful Things",
            "Beading Hearts",
            "Beadniks",
            "Bijouxanew",
            "Bizzy Beads",
            "BluGreen Jewelry",
            "BluMoon",
            "Buttons & Beads",
            "Chameleons",
            "Charming Crafts",
            "Chic and Artsy",
            "Chicas",
            "Chokers and Charms",
            "Classical Customs",
            "Classics Jewelry",
            "Colorful Stardust",
            "Creative Incarnations",
            "Creative Rage",
            "Creative Recycling",
            "Cultured Curio",
            "CuriousBead",
            "Custom Chic",
            "Deja Jewel",
            "Diamond Bead",
            "Diamond Light Nebula",
            "Diamond Sea",
            "Diamonds",
            "Discoveries",
            "Doodads",
            "Earth Unique Jewelry",
            "Ecletic Creations",
            "Elements: Wearable Art",
            "Embellished Life",
            "Euphorium Jewel Design",
            "Fab Jewels",
            "Firebird Jewels",
            "Foozles",
            "Grace of Hearts",
            "Green Chic",
            "Holidaze Jewelry",
            "Ice Jewelers",
            "Illuminate Jewelers",
            "Illuminated Accessories",
            "Infinity Jewelers",
            "Jenewal",
            "Jeweled Feather",
            "JewelJest",
            "Jewelry Junkie",
            "Jewelry Palace",
            "Jewels and Gems",
            "Jewelure",
            "Journey Jewelry",
            "Just Bead It",
            "Kaleidescopes",
            "Kobbled",
            "Lux Fine Jewelry",
            "Made For Her",
            "Magic Clasp Jewelry",
            "Memories Jewelry & Beads",
            "Metal Spectrum Jewelry Store",
            "Metamorphic Creations",
            "Mingled Spectrum",
            "Mixed Media Mutations",
            "Moxie",
            "Mr. Sparklez Emporium",
            "New Born Bead",
            "New Life Designs",
            "New Life Inventions",
            "Original Adornments",
            "Ornamental Phoenix",
            "Pandora's Box",
            "Past to Present",
            "Phoenix Creations",
            "Redazzled",
            "Redonez",
            "Regal Creations",
            "Relics to Riches",
            "Restoration Beads",
            "ReTrend",
            "RetroChic Jewelry",
            "Revibrant",
            "Ring of Memories Jewelers",
            "Rocks",
            "Royal Bloom Creations",
            "Sparkles Shop",
            "Special Engagements Jewelers",
            "Spirited ReCreations",
            "Spring Jewelers",
            "Stone Appeal",
            "Stranded Memories",
            "Sunkissed Jewelry",
            "The Beadhaus",
            "The Diamond Band",
            "The Galleria of Gems",
            "The Gemstone Gallery",
            "The Golden Goose",
            "The Looking Glass Jewelers",
            "The Platinum People",
            "The Velvet Box",
            "Thrifty Trinkets",
            "Tiger's Eye Oasis",
            "Tiny Collage Studios",
            "Touch of Gold",
            "Transforming Trinkets",
            "Treasure Gems",
            "Treasurebox",
            "Treasurer",
            "Trinity Jewelers & Co.",
            "The Chic and Some Wire",
            "Uncommon Jewelry",
            "Uniqness",
        ]
        return choice(j1)


class Blacksmith(Store):
    @staticmethod
    def generate():
        b1 = [
            "A Steel",
            "Adore Ore",
            "Anvil Crafts",
            "Anvil Mastery",
            "Anvil Works",
            "Anything Metal",
            "Arms of Steel",
            "Ball of Fire",
            "Balls of Fire",
            "Baptisms of Fire",
            "Bars of Steel",
            "Beat the Heat",
            "Beats of Fire",
            "Belly Fires",
            "Between Hammer and Anvil",
            "Blackstone Forge",
            "Blazing Blacksmiths",
            "Blazing Glory",
            "Blazing Trails",
            "Bloodbath & Beyond",
            "Blue Blazes",
            "Blue Steel",
            "Breathing Fire",
            "By Hammer and Hand",
            "By Hammer and Tongs",
            "Clamor Glamor",
            "Clamorize",
            "Clink 'n Clank",
            "Clobbering Time",
            "Curious Forge",
            "Dame of Flame",
            "Fame of Flame",
            "Fire & Brimstone",
            "Fire It Up",
            "Flame of Fame",
            "Flux Crux",
            "Flux Deluxe",
            "Forge and Fabricate",
            "Forge away",
            "Forging Ahead",
            "Forging Matters",
            "George's Forge",
            "Gorge 'n Forge",
            "Hammer 'n Anvil",
            "Hammer Clamor",
            "Hammer Down",
            "Hammer Glamor",
            "Hammer Home",
            "Hammer It Hot",
            "Hammer Out",
            "Hammer Time",
            "Hammer and Metal",
            "Hammer and Tongs",
            "Hammer in Hand",
            "He Who Smelt It",
            "Heat Up",
            "Heat of the Moment",
            "Heavy Metal Works",
            "Heavy Metals",
            "Hot Hammer",
            "Hot Hot Hot",
            "Hot Iron",
            "Hot Rod",
            "Hot Spot",
            "Hot Stuff",
            "Hot diggety dog!",
            "Hot diggety!",
            "Hot-Shot",
            "In Flux",
            "Ingot This",
            "Iron Designs",
            "Iron Man",
            "Iron Woman",
            "Iron in the Fire",
            "Ironclad",
            "Just Enough Irons",
            "Like Moths",
            "Making It Hot",
            "Matter of Metal",
            "Metal Accent",
            "Metal Arts",
            "Metal Expertise",
            "Metal Fabrications",
            "Metal Mania",
            "Metal Maniac",
            "Metal Mastery",
            "Metal Pandemonium",
            "Metal Trades",
            "Metal Works",
            "Metallurgy",
            "Metalworks",
            "Metalworks of Art",
            "Mind Over Matter",
            "Mind Over Metal",
            "Mineral Minded",
            "Mineral Works",
            "Mr Smith",
            "Mrs Smith",
            "Nerves of Steel",
            "Nice Ring To It",
            "Ore Decor",
            "Ore Else",
            "Ore Galore",
            "Ore Really",
            "Ore Restore",
            "Ore Store",
            "Parent Rock",
            "Phoenix Fire",
            "Pound World",
            "Real Steel",
            "Ring to It",
            "Rings True",
            "Smelt Art",
            "Smelt My Hearth",
            "Smelt in my Arms",
            "Smelting Pot",
            "Smelts of Heaven",
            "Smelts of Roses",
            "Smite Thee",
            "Smith Thee",
            "Smithen",
            "Smitten",
            "Sparks and Flames",
            "Squeal of Steel",
            "Steel Appeal",
            "Steel Arms",
            "Steel Base.py",
            "Steel Fabrications",
            "Steel Ideal",
            "Steel Show",
            "Steel Thunder",
            "Steel Wings",
            "Stop! Hammer Time",
            "Striking Hot",
            "Sword in the Forge",
            "Sword in the Stone",
            "The Ancient Anvil",
            "The Blacksmith's Forge",
            "The Clamor Shop",
            "The Clank Tank",
            "The Clinker Shop",
            "The Cobalt Forge",
            "The Eternal Flame",
            "The Fire Spire",
            "The Fire Squire",
            "The Flame Game",
            "The Gorge Forge",
            "The Heat is On",
            "The Hot Forge",
            "The Hot Ticket",
            "The Inferno Forge",
            "The Iron's Hot",
            "The Metal Petal",
            "The Phoenix Forge",
            "The Right Clank",
            "The Smelt Belt",
            "The Smelt Celt",
            "The Smith Myth",
            "The Smithy",
            "The Storm Forge",
            "The Tilted Anvil",
            "The Unbreakable Anvil",
            "There Be Smoke",
            "True as Steel",
            "Under Construction",
            "While the Iron's Hot",
            "Young Flames",
        ]
        return choice(b1)


class General(Store):
    @staticmethod
    def generate():
        n1 = [
            "Abiding",
            "Acclaimed",
            "Acquired",
            "Adapt",
            "Admired",
            "Admiring",
            "Adorable",
            "Affordable",
            "Aggressive",
            "Agreeing",
            "Amazing",
            "Amusing",
            "Ancient",
            "Angelic",
            "Angry",
            "Antique",
            "Arriving",
            "Awesome",
            "Awkward",
            "Baby",
            "Baking",
            "Balanced",
            "Basic",
            "Bathing",
            "Beautiful",
            "Begging",
            "Better",
            "Big",
            "Bitter",
            "Black",
            "Blank",
            "Bleeding",
            "Blind",
            "Blissful",
            "Blond",
            "Blue",
            "Blushing",
            "Bouncing",
            "Bouncy",
            "Brass",
            "Bright",
            "Brilliant",
            "Broken",
            "Bronze",
            "Brown",
            "Burning",
            "Busy",
            "Calculating",
            "Calm",
            "Careful",
            "Challenging",
            "Cheap",
            "Cheating",
            "Cheering",
            "Clean",
            "Clever",
            "Colorful",
            "Common",
            "Complaining",
            "Confused",
            "Corrupt",
            "Corrupted",
            "Courageous",
            "Crafty",
            "Crazy",
            "Creeping",
            "Cuddly",
            "Curly",
            "Dancing",
            "Dapper",
            "Dark",
            "Dazzling",
            "Defiant",
            "Deserving",
            "Dirty",
            "Dizzy",
            "Drawing",
            "Dreaming",
            "Dry",
            "Eager",
            "Early",
            "Earnest",
            "Educated",
            "Elder",
            "Elegant",
            "Elementary",
            "Empty",
            "Evil",
            "Exalted",
            "Excited",
            "Expensive",
            "Expert",
            "Fabulous",
            "Fading",
            "Fair",
            "Fake",
            "False",
            "Famous",
            "Fancy",
            "Fantastic",
            "Fast",
            "Flawless",
            "Flimsy",
            "Floating",
            "Flowing",
            "Fluffy",
            "Forsaken",
            "Fresh",
            "Frozen",
            "Gentle",
            "Glass",
            "Glittering",
            "Glorious",
            "Glowing",
            "Golden",
            "Gorgeous",
            "Graceful",
            "Gracious",
            "Greedy",
            "Green",
            "Grim",
            "Groaning",
            "Growing",
            "Grumpy",
            "Guarding",
            "Hairy",
            "Happy",
            "Hasty",
            "Haunting",
            "Heavy",
            "Hidden",
            "Hiding",
            "Honest",
            "Honored",
            "Huge",
            "Humble",
            "Humming",
            "Hungry",
            "Imaginary",
            "Infamous",
            "Intelligent",
            "Invincible",
            "Invisible",
            "Iron",
            "Ironclad",
            "Jaded",
            "Jealous",
            "Joking",
            "Jolly",
            "Juicy",
            "Jumbo",
            "Jumping",
            "Kicking",
            "Kind",
            "Kissing",
            "Kneeling",
            "Large",
            "Last",
            "Laughing",
            "Lazy",
            "Light",
            "Listening",
            "Little",
            "Lonely",
            "Long",
            "Loving",
            "Loyal",
            "Lucky",
            "Mad",
            "Majestic",
            "Marching",
            "Mellow",
            "Melting",
            "Merry",
            "Misty",
            "Muddy",
            "Mushy",
            "Naughty",
            "Needy",
            "New",
            "Nodding",
            "Nutty",
            "Old",
            "Orange",
            "Ordinary",
            "Perfect",
            "Performing",
            "Phony",
            "Pink",
            "Plain",
            "Pleasant",
            "Popular",
            "Praying",
            "Preaching",
            "Precious",
            "Pretty",
            "Purple",
            "Puzzled",
            "Quick",
            "Quiet",
            "Racing",
            "Rainy",
            "Rapid",
            "Rare",
            "Reading",
            "Red",
            "Rhyming",
            "Rolling",
            "Royal",
            "Running",
            "Sad",
            "Sandy",
            "Scary",
            "Screaming",
            "Searching",
            "Second",
            "Secret",
            "Seeking",
            "Serene",
            "Shady",
            "Shaking",
            "Shaving",
            "Shrugging",
            "Silly",
            "Silver",
            "Sleek",
            "Sleeping",
            "Small",
            "Smart",
            "Smelly",
            "Smoking",
            "Sneaky",
            "Sparkling",
            "Steel",
            "Storm",
            "Stormy",
            "Striped",
            "Sunny",
            "Sweet",
            "Swimming",
            "Talking",
            "Tall",
            "Tasty",
            "Thirsty",
            "Thunder",
            "Tiny",
            "Tired",
            "Trusty",
            "Ugly",
            "Unique",
            "Unlucky",
            "Velvet",
            "Vicious",
            "Violet",
            "Walking",
            "Wandering",
            "Watching",
            "Waving",
            "Weeping",
            "Wet",
            "Whimsical",
            "Whispering",
            "Whistling",
            "White",
            "Wicked",
            "Wild",
            "Winking",
            "Wise",
            "Wishing",
            "Worthy",
            "Wrestling",
            "Yawning",
            "Yelling",
            "Yellow",
            "Young",
        ]
        n2 = [
            "Adventure",
            "Android",
            "Antenna",
            "Anvil",
            "Apple",
            "Armor",
            "Arsenal",
            "Asteroid",
            "Bear",
            "Bed",
            "Bee",
            "Berry",
            "Bird",
            "Bite",
            "Blade",
            "Blossom",
            "Boar",
            "Board",
            "Boat",
            "Bomb",
            "Book",
            "Boulder",
            "Bowl",
            "Brush",
            "Bull",
            "Cake",
            "Canvas",
            "Cape",
            "Captain",
            "Car",
            "Caravan",
            "Carpet",
            "Carriage",
            "Carrot",
            "Cart",
            "Castle",
            "Cat",
            "Chariot",
            "Cherry",
            "Chestnut",
            "Chimney",
            "Cloak",
            "Clock",
            "Comet",
            "Compass",
            "Cow",
            "Crate",
            "Crow",
            "Cup",
            "Curtain",
            "Cyborg",
            "Day",
            "Disguise",
            "Dish",
            "Dog",
            "Door",
            "Drape",
            "Dress",
            "Duck",
            "Dwarf",
            "Eagle",
            "Eel",
            "Elf",
            "Elixir",
            "Expanse",
            "Expedition",
            "Face",
            "Feather",
            "Fire",
            "Fish",
            "Flower",
            "Forest",
            "Fork",
            "Frame",
            "Frog",
            "Furnace",
            "Ghost",
            "Giant",
            "Gnome",
            "Goose",
            "Grape",
            "Growth",
            "Guard",
            "Gull",
            "Hammer",
            "Hazelnut",
            "Hog",
            "Horse",
            "Hunt",
            "Jester",
            "Joker",
            "Journey",
            "Jug",
            "Kettle",
            "Kite",
            "Knife",
            "Lemon",
            "Mammoth",
            "Mantle",
            "Mark",
            "Mask",
            "Melon",
            "Mill",
            "Mirror",
            "Model",
            "Monkey",
            "Moon",
            "Mountain",
            "Mouse",
            "Mug",
            "Note",
            "Nut",
            "Oven",
            "Owl",
            "Pagoda",
            "Painting",
            "Pantheon",
            "Peach",
            "Peacock",
            "Peanut",
            "Pear",
            "Pen",
            "Pencil",
            "Pepper",
            "Phantom",
            "Phone",
            "Pig",
            "Pixy",
            "Plane",
            "Plate",
            "Plum",
            "Pond",
            "Pony",
            "Pot",
            "Potato",
            "Pygmy",
            "Quarry",
            "Quest",
            "Quill",
            "Radio",
            "Raven",
            "Record",
            "Remote",
            "River",
            "Road",
            "Robot",
            "Rocket",
            "Rug",
            "Sail",
            "Screen",
            "Search",
            "Shark",
            "Shawl",
            "Shield",
            "Ship",
            "Shoe",
            "Shrimp",
            "Shrine",
            "Sign",
            "Snowman",
            "Spaceship",
            "Spoon",
            "Star",
            "Stone",
            "Stove",
            "Sword",
            "TV",
            "Table",
            "Tankard",
            "Temple",
            "Ticker",
            "Timer",
            "Tome",
            "Tooth",
            "Tower",
            "Train",
            "Traveller",
            "Tree",
            "Tribute",
            "Tusk",
            "Voyage",
            "Wall",
            "Walnut",
            "Watch",
            "Weapon",
            "Window",
            "Wolf",
            "World",
            "Writer",
        ]
        n3 = [
            "Store",
            "Tradepost",
            "Grocer",
            "Hardware Store",
            "Hobby Store",
            "Kitchens",
            "Liquor Store",
            "Market",
            "Pawn",
            "Pet Store",
            "Pharmacy",
            "Pub",
            "Repairs",
        ]

        return choice(n1) + " " + choice(n2) + " " + choice(n3)


class Town(Store):
    @staticmethod
    def generate():
        nm1 = [
            "amber",
            "angel",
            "spirit",
            "basin",
            "lagoon",
            "basin",
            "arrow",
            "autumn",
            "bare",
            "bay",
            "beach",
            "bear",
            "bell",
            "black",
            "bleak",
            "blind",
            "bone",
            "boulder",
            "bridge",
            "brine",
            "brittle",
            "bronze",
            "castle",
            "cave",
            "chill",
            "clay",
            "clear",
            "cliff",
            "cloud",
            "cold",
            "crag",
            "crow",
            "crystal",
            "curse",
            "dark",
            "dawn",
            "dead",
            "deep",
            "deer",
            "demon",
            "dew",
            "dim",
            "dire",
            "dirt",
            "dog",
            "dragon",
            "dry",
            "dusk",
            "dust",
            "eagle",
            "earth",
            "east",
            "ebon",
            "edge",
            "elder",
            "ember",
            "ever",
            "fair",
            "fall",
            "false",
            "far",
            "fay",
            "fear",
            "flame",
            "flat",
            "frey",
            "frost",
            "ghost",
            "glimmer",
            "gloom",
            "gold",
            "grass",
            "gray",
            "green",
            "grim",
            "grime",
            "hazel",
            "heart",
            "high",
            "hollow",
            "honey",
            "hound",
            "ice",
            "iron",
            "kil",
            "knight",
            "lake",
            "last",
            "light",
            "lime",
            "little",
            "lost",
            "mad",
            "mage",
            "maple",
            "mid",
            "might",
            "mill",
            "mist",
            "moon",
            "moss",
            "mud",
            "mute",
            "myth",
            "never",
            "new",
            "night",
            "north",
            "oaken",
            "ocean",
            "old",
            "ox",
            "pearl",
            "pine",
            "pond",
            "pure",
            "quick",
            "rage",
            "raven",
            "red",
            "rime",
            "river",
            "rock",
            "rogue",
            "rose",
            "rust",
            "salt",
            "sand",
            "scorch",
            "shade",
            "shadow",
            "shimmer",
            "shroud",
            "silent",
            "silk",
            "silver",
            "sleek",
            "sleet",
            "sly",
            "small",
            "smooth",
            "snake",
            "snow",
            "south",
            "spring",
            "stag",
            "star",
            "steam",
            "steel",
            "steep",
            "still",
            "stone",
            "storm",
            "summer",
            "sun",
            "swamp",
            "swan",
            "swift",
            "thorn",
            "timber",
            "trade",
            "west",
            "whale",
            "whit",
            "white",
            "wild",
            "wilde",
            "wind",
            "winter",
            "wolf",
        ]
        nm2 = [
            "acre",
            "band",
            "barrow",
            "bay",
            "bell",
            "born",
            "borough",
            "bourne",
            "breach",
            "break",
            "brook",
            "burgh",
            "burn",
            "bury",
            "cairn",
            "call",
            "chill",
            "cliff",
            "coast",
            "crest",
            "cross",
            "dale",
            "denn",
            "drift",
            "fair",
            "fall",
            "falls",
            "fell",
            "field",
            "ford",
            "forest",
            "fort",
            "front",
            "frost",
            "garde",
            "gate",
            "glen",
            "grasp",
            "grave",
            "grove",
            "guard",
            "gulch",
            "gulf",
            "hall",
            "hallow",
            "ham",
            "hand",
            "harbor",
            "haven",
            "helm",
            "hill",
            "hold",
            "holde",
            "hollow",
            "horn",
            "host",
            "keep",
            "land",
            "light",
            "maw",
            "meadow",
            "mere",
            "mire",
            "mond",
            "moor",
            "more",
            "mount",
            "mouth",
            "pass",
            "peak",
            "point",
            "pond",
            "port",
            "post",
            "reach",
            "rest",
            "rock",
            "run",
            "scar",
            "shade",
            "shear",
            "shell",
            "shield",
            "shore",
            "shire",
            "side",
            "spell",
            "spire",
            "stall",
            "wich",
            "minster",
            "star",
            "storm",
            "strand",
            "summit",
            "tide",
            "town",
            "vale",
            "valley",
            "vault",
            "vein",
            "view",
            "ville",
            "wall",
            "wallow",
            "ward",
            "watch",
            "water",
            "well",
            "wharf",
            "wick",
            "wind",
            "wood",
            "yard",
        ]

        return choice(nm1).title() + choice(nm2)


class Brothel(Store):
    @staticmethod
    def generate():
        s = [
            "Daisies",
            "The Don",
            "Blinkers",
            "The Prudes Suspenders",
            "Gold's Dust",
            "The Velvet Fang",
            "The Whisper Home",
            "The Hook",
            "Over the River",
            "Slooshes",
            "The Rapid Rascal",
            "The Stoat",
            "The Fidgety Ferret",
            "Long Shaft",
            "The Guards",
            "Chastity's",
            "The Mask",
            "The Red Dress",
            "Jewels",
            "Silken Flute",
            "The Nag's Head",
            "Drummers",
            "Sailors Choice",
            "Blacksmiths Envy",
            "The Nagging Wife",
            "Colins Rubble",
            "Drons Beat",
            "The Wink",
            "Maggie's Horn",
            "The Sun & Cider",
            "The Oakworm",
            "Tickle & Feather",
            "The Mistress",
            "Madam Zersannies",
            "The Kings Court",
            "The Cursed Coin",
            "Slit",
            "The Maiden Head",
            "The Silken Ferret",
            "Long Legs",
            "Elven Whispers",
            "The Leg",
            "False Suspenders",
            "Aunt Fannies Bloomers",
            "Final Rest",
            "Cocks Crow",
            "The Unblinking Eye",
            "The Bountiful Bosom",
            "Tuskers",
            "The Thrusting Gentleman",
            "Tally Hoes",
            "Rutting",
            "Pigs in Blankets",
            "The Delicate Touch",
            "Aphrodite's Wish",
            "The Dirty Secret",
            "Long Locks",
            "Sweat",
            "Brothel",
            "Taters",
            "The Swift Finish",
            "Cumberlands",
            "The Missing Sausage",
            "The Fools Frolic",
            "Dragons",
            "The Bushel",
            "Farmers Oats",
            "The Raised Brow",
            "Genies",
            "The Farfetched Feather",
            "Junk",
            "The Connoisseur's Choice",
            "Colossus",
            "The Smooth Ride",
            "Bucking",
            "The Great Big Globes",
            "The Glimmeric",
            "Loving Embrace",
            "Chokers Necklace",
            "The Grand Madams Emporium of Fine Delicacies, Treats, and the Exotic",
            "Thug's Retreat",
            "Warriors Return",
            "Gold Gobblers",
            "Cackling Croons",
            "The Warty",
            "Bessie's Best",
            "Corset",
            "Winkies",
            "The Shagger",
            "Port of Call",
            "The Home away from Hoes",
            "Smooth",
            "The Maiden Fair",
            "The Bit",
            "Hosted",
            "Glamourous Delights",
            "Happily Ever After",
            "Sultry Stare",
            "The Full Flush",
            "The Dark Cavern",
            "The Deep Thoroughfare",
            "The Hidden Depths",
            "The Massive Oak",
            "The Tall Mast",
            "The Quivering Hills",
            "The Steamy Engine",
            "The Lair of the Two-Backed Beast",
            "The Row of Rigid Spears",
            "Sultry Scullion",
            "The Rusty Pipe",
            "Ye Old Festhall",
            "Shambling Mounds",
            "The Out Inn",
            "The Shagging Carpet",
            "The Plot Hole",
            "The Pink Hydra",
            "The Gelatinous Cube",
            "The Locked Gauntlet",
            "Ten Foot Ladder",
            "The Come and Go",
            "The Clockwork Dollhouse",
            "The Wild Wild West",
            "The Very Jolly Roger",
            "This is Not a Brothel",
            "The Salty Clam",
            "Classy Lassies",
            "Tally Hoes",
            "Breast Buy",
            "Pussy Galore",
            "The Lancer's Tilt",
            "The Piston",
            "The Wandering Eye",
            "The Sure Thing",
            "What Awaits",
            "Nothing and More",
            "The Minotaurs Horn",
            "The Witches Wiggle",
            "The Fighting Buck",
            "The Noble Nymph",
            "The Portly Sorcerer",
            "The Shag Pile",
            "The Spoony Bardesses",
            "The Greasy Wheel",
            "Pretty & Witty & Gay",
            "The Purple Party Pantaloons",
            "The Ascended Kobold",
            "Pick - a - Dilly Square",
            "The Paladin's Mount",
            "The Kitty and the Rooster",
            "The Pearl",
            "Iron Heart Surge",
            "We Sell Scrolls of Remove Disease",
            "The Masterwork Stirrup",
            "The Ten Foot Pole",
            "The Prancing Pink Party Pony",
            "A Whore of a Different Color",
            "The Halfling's Quarterstaff",
            "Crank Shaft Grinders",
            "The Rusty Scabbard",
            "The Lady Hole",
            "The Pink Lagoon",
            "The Clam Shack",
            "The Piping Pie Inn",
            "Sadie's Sweet Meats",
            "The Breach",
            "The Easy Cleaver",
            "The Easy Beaver",
            "The Eager Beaver",
            "The Wet Seal",
            "The Gap",
            "Maiden's Kiss",
            "The Cumly Maden",
            "The Milk Depository",
            "The Butter Factory",
            "The Milking Station",
            "The Milk Maid's Inn",
            "The Ruddy Knees Inn",
            "The Sqeaky Wheel",
            "The Bicycle Club",
            "The Riding Club",
            "The Jockey's Club ",
            "The Glass Blower",
            "The Beer Goggles",
            "Balloon Ride",
            "The Tank and Spank",
            "Bigby's Enjoyable Hand",
            "Mordenkainen's Luxurious Loveshack",
            "Otiluke's Spheres",
            "Flurry of Blows",
            "Butterchurn",
            "Happy Eel",
            "Rose Garden",
            "The Changeling's Secret",
            "The Portable Hole",
            "Century Worm",
            "Rod of Lordly Might",
            "Robe of Bones",
            "The Bread Gazebo",
            "Just an Ordinary Storefront",
            "Aunty's Helping Hands",
            "The Bearded Clam",
            "The Smurven Hammer",
            "The Ramrod.",
            "The Truss 'n Stuff",
            "The Rowdy Beaver",
            "The Love Bite",
            "The Love Tap",
            "The Hate Hit",
            "The Sucking Succubus",
            "House of Heavenly Delights",
            "Guild For The Oldest Job",
            "Lady Marmalade's House",
            "Cunning Linguists Guild",
            "The Rocking Horses",
            "House of Hung Harrys",
            "Rod of Wonder",
            "Lords of Rodly Might",
            "Gloryhouse",
            "The Healing Surge",
            "The Sunken Pole",
            "The Mosquito's Rest",
            "The Spring and Flange Assembly",
            "Afternoon's Delight",
            "The Blue Oyster",
            "The Gaudy Bawdy",
            "The Pickled Pecker",
            "The Loose Rudder",
            "The Rusty Rollocks",
            "The Wandering Tiller",
            "The Able Seamen",
            "Steppin the Mast",
            "The Wayward Bouy",
            "The Fish Net Inn",
            "The Glorious Booty",
            "The Precious Booty",
            "The Salty Transmission",
            "Den of Iniquity",
            "Massage Parlor",
            "The Red Door",
            "The Growing Cock",
            "The Swallowing Maiden",
            "Gobbling Girties",
        ]

        return choice(s)


class Gunsmith(Store):
    @staticmethod
    def generate():
        s1 = [
            "Abomination",
            "Agony",
            "Allegiance",
            "Alpha",
            "Amigo",
            "Amnesia",
            "Apocalypse",
            "Armageddon",
            "Ash",
            "Ashes",
            "Atomic Annie",
            "Baby",
            "Battery",
            "Battlestar",
            "Betrayal",
            "Betrayer",
            "Big Bertha",
            "Mighty Mouse",
            "Betty",
            "Quick Fix",
            "Swiftscope",
            "Bad Medicine",
            "Toots",
            "Enterprise",
            "Big Rhonda",
            "Crowd Control",
            "Intervention",
            "Matilda",
            "Pink Mist",
            "Judas",
            "Headhunter",
            "Jaeger",
            "Lupus",
            "Big Daddy",
            "Big Game",
            "Birthmark",
            "Blackout",
            "Bloodfury",
            "Bloodmoon",
            "Bloodrage",
            "Bloodspiller",
            "Bloodweep",
            "Bombardment",
            "Boomer",
            "Boomstick",
            "Brass Rain",
            "Brutality",
            "Brutalizer",
            "Bulldog",
            "Burn",
            "Burp",
            "Cataclysm",
            "Catastrophe",
            "Chance",
            "Chaos",
            "Comet",
            "Corpsemaker",
            "Corruption",
            "Cosmos",
            "Crash",
            "Crimson",
            "Crossfire",
            "Cruiser",
            "Crush",
            "Cyclone",
            "Daddy",
            "Damnation",
            "Darkness",
            "Dawn",
            "Deadeye",
            "Deathbringer",
            "Deathraze",
            "Decimation",
            "Demise",
            "Desolation",
            "Despair",
            "Destiny",
            "Destruction",
            "Devastation",
            "Devotion",
            "Devourer",
            "Discharge",
            "Disturbance",
            "Divine",
            "Dominance",
            "Dominion",
            "Doom",
            "Downpour",
            "Dragonmaw",
            "Dragonstrike",
            "Dreamhunter",
            "Due Diligence",
            "Early Retirement",
            "Echo",
            "Eclipse",
            "Emergency",
            "End of Dreams",
            "Endbringer",
            "Enigma",
            "Envy",
            "Epilogue",
            "Equality",
            "Equalizer",
            "Eternal Rest",
            "Eternity",
            "Eveningstar",
            "Extermination",
            "Extinction",
            "Falcon",
            "Falling Star",
            "Fate",
            "Finality",
            "Frankenlove",
            "Frankenstein",
            "Frenzy",
            "Fury",
            "Gov'ner",
            "Grace",
            "Harbinger",
            "Harmony",
            "Hatred",
            "Heat",
            "Hell's Scream",
            "Homage",
            "Honor's Call",
            "Hope's End",
            "Infamy",
            "Infinity",
            "Injection",
            "Interrogator",
            "Judged",
            "Justice",
            "Justifier",
            "King of Nines",
            "Knight's Fall",
            "Knightfall",
            "Lament",
            "Last Chance",
            "Last Laugh",
            "Last Rites",
            "Last Word",
            "Last Words",
            "Lazarus",
            "Legacy",
            "Legionaire",
            "Life's Limit",
            "Lightning",
            "Lightningflash",
            "Limbo",
            "Lockjaw",
            "Magma",
            "Malice",
            "Maneater",
            "Massacre",
            "Mercy",
            "Midnight",
            "Misery's End",
            "Moonsight",
            "Mortality",
            "Narcoleptic",
            "Night's Fall",
            "Nightbane",
            "Nightfall",
            "Nightmare",
            "Nighttime",
            "Nightwatch",
            "Nirvana",
            "Oathbreaker",
            "Oathkeeper",
            "Oblivion",
            "Ole Betsy",
            "Omega",
            "Optimist",
            "Orbit",
            "Party Pooper",
            "Patience",
            "Peacekeeper",
            "Peacemaker",
            "Pendulum",
            "Perfect Storm",
            "Persuasion",
            "Piety",
            "Popeye",
            "Pride",
            "Prophecy",
            "Pulse",
            "Punisher",
            "Purifier",
            "Rage",
            "Rapture",
            "Rattlesnake",
            "Reckoning",
            "Reign",
            "Remorse",
            "Requiem",
            "Retirement",
            "Rigormortis",
            "Salvation",
            "Salvo",
            "Scar",
            "Serenity",
            "Severance",
            "Shadowfury",
            "Shadowmoon",
            "Silence",
            "Snake",
            "Snapper",
            "Soulburn",
            "Sprocket",
            "Stalker",
            "Storm",
            "Storm Breaker",
            "Storm-Weaver",
            "Stormbringer",
            "Stormrider",
            "Sugar",
            "Sunshine",
            "Supernova",
            "Supremacy",
            "Suspension",
            "Swan Song",
            "Sweetie",
            "Syndrome",
            "Termination",
            "The Ambassador",
            "The Chancellor",
            "The End",
            "The Judge",
            "The Light",
            "The Oculus",
            "The Oracle",
            "The Pig",
            "The Void",
            "Thunder",
            "Thundercall",
            "Trauma",
            "Treachery",
            "Tremor",
            "Tribunal",
            "Tribute",
            "Trinity",
            "Trouble",
            "Twilight",
            "Typhoon",
            "Ubiquity",
            "Undoing",
            "Vacancy",
            "Valkyrie",
            "Vanquisher",
            "Vengeance",
            "Voice of Insanity",
            "Voice of Reason",
            "Warbringer",
            "Warmonger",
            "Whispers",
            "Whisperwind",
            "Wicked",
            "Widow Maker",
            "Willbreaker",
            "Wit's End",
            "Wolf",
        ]
        s2 = [
            "Apocalypse",
            "Apocalyptic",
            "Atuned",
            "Bandit's",
            "Baneful",
            "Banished",
            "Barbaric",
            "Battleworn",
            "Blood Infused",
            "Blood-Forged",
            "Bloodied",
            "Bloodlord's",
            "Bloodsurge",
            "Brutal",
            "Brutality",
            "Burnished",
            "Cataclysm",
            "Cataclysmic",
            "Challenger",
            "Challenger's",
            "Champion",
            "Cold-Forged",
            "Commando",
            "Commando's",
            "Conqueror",
            "Conqueror's",
            "Corroded",
            "Corrupted",
            "Crazed",
            "Dancing",
            "Dark",
            "Darkness",
            "Defender",
            "Defender's",
            "Defiled",
            "Defiling",
            "Deluded",
            "Deserted",
            "Desire's",
            "Desolation",
            "Destiny's",
            "Diabolical",
            "Dire",
            "Doom",
            "Doom's",
            "Eerie",
            "Engraved",
            "Eternal",
            "Exiled",
            "Extinction",
            "Faith's",
            "Faithful",
            "Fancy",
            "Fearful",
            "Feral",
            "Ferocious",
            "Fierce",
            "Fireguard",
            "Firestorm",
            "Forsaken",
            "Fortune's",
            "Foul",
            "Frenzied",
            "Furious",
            "Fusion",
            "Ghastly",
            "Ghostly",
            "Gladiator",
            "Gleaming",
            "Glinting",
            "Greedy",
            "Grieving",
            "Grim",
            "Guard's",
            "Guardian's",
            "Guerilla",
            "Hateful",
            "Heartless",
            "Heinous",
            "Hero",
            "Hero's",
            "Honed",
            "Honor's",
            "Hopeless",
            "Howling",
            "Hungering",
            "Incarnated",
            "Infantry",
            "Infantry's",
            "Infused",
            "Inherited",
            "Judgement",
            "Keeper's",
            "Legionnaire's",
            "Liar's",
            "Lightning",
            "Lonely",
            "Loyal",
            "Lustful",
            "Lusting",
            "Malevolent",
            "Malicious",
            "Malificent",
            "Malignant",
            "Massive",
            "Mended",
            "Mercenary",
            "Military",
            "Misfortune's",
            "Mourning",
            "Nightmare",
            "Oathkeeper's",
            "Ominous",
            "Peacekeeper",
            "Peacekeeper's",
            "Phantom",
            "Polished",
            "Pride's",
            "Prideful",
            "Primal",
            "Prime",
            "Primitive",
            "Private",
            "Promised",
            "Protector's",
            "Proud",
            "Pure",
            "Raging",
            "Recruit's",
            "Refined",
            "Reforged",
            "Reincarnated",
            "Relentless",
            "Remorseful",
            "Renewed",
            "Renovated",
            "Replica",
            "Restored",
            "Retribution",
            "Ritual",
            "Roaring",
            "Savage",
            "Sentinel",
            "Shadow",
            "Silent",
            "Singed",
            "Singing",
            "Sinister",
            "Smooth",
            "Soldier's",
            "Solitude's",
            "Sorrow's",
            "Soulless",
            "Spectral",
            "Spiteful",
            "Storm",
            "Storm-Forged",
            "Stormfury",
            "Stormguard",
            "Terror",
            "Thirsting",
            "Thirsty",
            "Thunder",
            "Thunder-Forged",
            "Thunderfury",
            "Thunderguard",
            "Thundersoul",
            "Thunderstorm",
            "Timeworn",
            "Trainee's",
            "Treachery's",
            "Trooper",
            "Twilight",
            "Twilight's",
            "Twisted",
            "Tyrannical",
            "Vanquisher",
            "Vengeance",
            "Vengeful",
            "Veteran",
            "Veteran's",
            "Vicious",
            "Victor",
            "Vile",
            "Vindication",
            "Vindicator",
            "Vindictive",
            "Void",
            "Vowed",
            "War",
            "War-Forged",
            "Warden's",
            "Warlord's",
            "Warmonger",
            "Warmonger's",
            "Warp",
            "Warped",
            "Warrior",
            "Warrior's",
            "Whistling",
            "Wicked",
            "Windsong",
            "Woeful",
            "Wrathful",
            "Wretched",
            "Yearning",
            "Zealous",
        ]
        s3 = [
            "Bronze",
            "Bronzed",
            "Ivory",
            "Ebon",
            "Glass",
            "Golden",
            "Gilded",
            "Chromed",
            "Iron",
            "Stainless",
            "Carbon",
            "Brass",
            "Fiberglass",
            "Ironbark",
            "Mithril",
            "Obsidian",
            "Silver",
            "Steel",
            "Titanium",
        ]
        s4 = [
            "Rifle",
            "Carbine",
            "Blaster",
            "Fusil",
            "Launcher",
            "Shooter",
            "Repeater",
            "Sniper",
            "Longrifle",
        ]
        s5 = [
            "Agent",
            "Allegiance",
            "Ambassador",
            "Annihilation",
            "Bearer",
            "Betrayer",
            "Blaster",
            "Bond",
            "Boomstick",
            "Boon",
            "Breaker",
            "Bringer",
            "Bruiser",
            "Butcher",
            "Call",
            "Carbine",
            "Carrier",
            "Champion",
            "Conqueror",
            "Courier",
            "Crier",
            "Crusader",
            "Crusher",
            "Cry",
            "Cunning",
            "Dawn",
            "Defender",
            "Defiler",
            "Delegate",
            "Destroyer",
            "Dispatcher",
            "Disposer",
            "Emissary",
            "Ender",
            "Envoy",
            "Executioner",
            "Favor",
            "Ferocity",
            "Foe",
            "Fusil",
            "Gift",
            "Glory",
            "Guardian",
            "Harbinger",
            "Heirloom",
            "Herald",
            "Hope",
            "Incarnation",
            "Last Hope",
            "Last Stand",
            "Launcher",
            "Legacy",
            "Longrifle",
            "Memory",
            "Messenger",
            "Might",
            "Musket",
            "Oath",
            "Pact",
            "Pledge",
            "Pounder",
            "Promise",
            "Prophecy",
            "Protector",
            "Queller",
            "Ravager",
            "Reach",
            "Reaper",
            "Repeater",
            "Rifle",
            "Scepter",
            "Sculptor",
            "Secret",
            "Shooter",
            "Shotgun",
            "Slayer",
            "Smasher",
            "Sniper",
            "Soul",
            "Suppressor",
            "Terror",
            "Token",
            "Tribute",
            "Vengeance",
            "Voice",
            "Whisper",
            "Wit",
        ]
        s6 = [
            "of Agony",
            "of Ancient Power",
            "of Anguish",
            "of Ashes",
            "of Assassins",
            "of Black Magic",
            "of Blessed Fortune",
            "of Blessings",
            "of Blight",
            "of Blood",
            "of Bloodlust",
            "of Broken Bones",
            "of Broken Dreams",
            "of Broken Families",
            "of Burdens",
            "of Chaos",
            "of Closing Eyes",
            "of Conquered Worlds",
            "of Corruption",
            "of Cruelty",
            "of Cunning",
            "of Dark Magic",
            "of Dark Souls",
            "of Darkness",
            "of Decay",
            "of Deception",
            "of Degradation",
            "of Delusions",
            "of Denial",
            "of Desecration",
            "of Diligence",
            "of Dismay",
            "of Dragonsouls",
            "of Due Diligence",
            "of Echoes",
            "of Ended Dreams",
            "of Ending Hope",
            "of Ending Misery",
            "of Eternal Bloodlust",
            "of Eternal Damnation",
            "of Eternal Glory",
            "of Eternal Justice",
            "of Eternal Rest",
            "of Eternal Sorrow",
            "of Eternal Struggles",
            "of Eternity",
            "of Executions",
            "of Faded Memories",
            "of Fallen Souls",
            "of Fools",
            "of Frost",
            "of Frozen Hells",
            "of Fury",
            "of Giants",
            "of Giantslaying",
            "of Grace",
            "of Grieving Widows",
            "of Hate",
            "of Hatred",
            "of Hell's Games",
            "of Hellish Torment",
            "of Heroes",
            "of Holy Might",
            "of Honor",
            "of Hope",
            "of Horrid Dreams",
            "of Horrors",
            "of Illuminated Dreams",
            "of Illumination",
            "of Immortality",
            "of Inception",
            "of Infinite Trials",
            "of Insanity",
            "of Invocation",
            "of Justice",
            "of Light's Hope",
            "of Lost Comrades",
            "of Lost Hope",
            "of Lost Voices",
            "of Lost Worlds",
            "of Magic",
            "of Mercy",
            "of Misery",
            "of Mountains",
            "of Mourning",
            "of Mystery",
            "of Necromancy",
            "of Nightmares",
            "of Oblivion",
            "of Perdition",
            "of Phantoms",
            "of Power",
            "of Pride",
            "of Pride's Fall",
            "of Putrefaction",
            "of Reckoning",
            "of Redemption",
            "of Regret",
            "of Riddles",
            "of Secrecy",
            "of Secrets",
            "of Shadow Strikes",
            "of Shadows",
            "of Shifting Sands",
            "of Shifting Worlds",
            "of Silence",
            "of Slaughter",
            "of Souls",
            "of Stealth",
            "of Storms",
            "of Subtlety",
            "of Suffering",
            "of Suffering's End",
            "of Summoning",
            "of Terror",
            "of Thunder",
            "of Time-Lost Memories",
            "of Timeless Battles",
            "of Titans",
            "of Torment",
            "of Traitors",
            "of Trembling Hands",
            "of Trials",
            "of Truth",
            "of Twilight's End",
            "of Twisted Visions",
            "of Unholy Blight",
            "of Unholy Might",
            "of Vengeance",
            "of Visions",
            "of Wasted Time",
            "of Widows",
            "of Wizardry",
            "of Woe",
            "of Wraiths",
            "of Zeal",
            "of the Ancients",
            "of the Banished",
            "of the Basilisk",
            "of the Beast",
            "of the Blessed",
            "of the Breaking Storm",
            "of the Brotherhood",
            "of the Burning Sun",
            "of the Caged Mind",
            "of the Cataclysm",
            "of the Champion",
            "of the Claw",
            "of the Corrupted",
            "of the Covenant",
            "of the Crown",
            "of the Damned",
            "of the Daywalker",
            "of the Dead",
            "of the Depth",
            "of the Dreadlord",
            "of the Earth",
            "of the East",
            "of the Emperor",
            "of the Empty Void",
            "of the End",
            "of the Enigma",
            "of the Fallen",
            "of the Falling Sky",
            "of the Flame",
            "of the Forest",
            "of the Forgotten",
            "of the Forsaken",
            "of the Gladiator",
            "of the Harvest",
            "of the Immortal",
            "of the Incoming Storm",
            "of the Insane",
            "of the King",
            "of the Lasting Night",
            "of the Leviathan",
            "of the Light",
            "of the Lion",
            "of the Lionheart",
            "of the Lone Victor",
            "of the Lone Wolf",
            "of the Lost",
            "of the Moon",
            "of the Moonwalker",
            "of the Night",
            "of the Night Sky",
            "of the Nightstalker",
            "of the North",
            "of the Occult",
            "of the Oracle",
            "of the Phoenix",
            "of the Plague",
            "of the Prince",
            "of the Protector",
            "of the Queen",
            "of the Serpent",
            "of the Setting Sun",
            "of the Shadows",
            "of the Sky",
            "of the South",
            "of the Stars",
            "of the Storm",
            "of the Summoner",
            "of the Sun",
            "of the Sunwalker",
            "of the Talon",
            "of the Undying",
            "of the Victor",
            "of the Void",
            "of the West",
            "of the Whispers",
            "of the Wicked",
            "of the Wind",
            "of the Wolf",
            "of the World",
            "of the Wretched",
        ]
        s7 = [
            "Abomination",
            "Agony",
            "Allegiance",
            "Alpha",
            "Amigo",
            "Amnesia",
            "Apocalypse",
            "Armageddon",
            "Ash",
            "Ashes",
            "Atomic Annie",
            "Baby",
            "Battery",
            "Battlestar",
            "Betrayal",
            "Betrayer",
            "Big Bertha",
            "Mighty Mouse",
            "Betty",
            "Quick Fix",
            "Swiftscope",
            "Bad Medicine",
            "Toots",
            "Enterprise",
            "Big Rhonda",
            "Crowd Control",
            "Intervention",
            "Matilda",
            "Pink Mist",
            "Judas",
            "Headhunter",
            "Jaeger",
            "Lupus",
            "Big Daddy",
            "Big Game",
            "Birthmark",
            "Blackout",
            "Bloodfury",
            "Bloodmoon",
            "Bloodrage",
            "Bloodspiller",
            "Bloodweep",
            "Bombardment",
            "Boomer",
            "Boomstick",
            "Brass Rain",
            "Brutality",
            "Brutalizer",
            "Bulldog",
            "Burn",
            "Burp",
            "Cataclysm",
            "Catastrophe",
            "Chance",
            "Chaos",
            "Comet",
            "Corpsemaker",
            "Corruption",
            "Cosmos",
            "Crash",
            "Crimson",
            "Crossfire",
            "Cruiser",
            "Crush",
            "Cyclone",
            "Daddy",
            "Damnation",
            "Darkness",
            "Dawn",
            "Deadeye",
            "Deathbringer",
            "Deathraze",
            "Decimation",
            "Demise",
            "Desolation",
            "Despair",
            "Destiny",
            "Destruction",
            "Devastation",
            "Devotion",
            "Devourer",
            "Discharge",
            "Disturbance",
            "Divine",
            "Dominance",
            "Dominion",
            "Doom",
            "Downpour",
            "Dragonmaw",
            "Dragonstrike",
            "Dreamhunter",
            "Due Diligence",
            "Early Retirement",
            "Echo",
            "Eclipse",
            "Emergency",
            "End of Dreams",
            "Endbringer",
            "Enigma",
            "Envy",
            "Epilogue",
            "Equality",
            "Equalizer",
            "Eternal Rest",
            "Eternity",
            "Eveningstar",
            "Extermination",
            "Extinction",
            "Falcon",
            "Falling Star",
            "Fate",
            "Finality",
            "Frankenlove",
            "Frankenstein",
            "Frenzy",
            "Fury",
            "Gov'ner",
            "Grace",
            "Harbinger",
            "Harmony",
            "Hatred",
            "Heat",
            "Hell's Scream",
            "Homage",
            "Honor's Call",
            "Hope's End",
            "Infamy",
            "Infinity",
            "Injection",
            "Interrogator",
            "Judged",
            "Justice",
            "Justifier",
            "King of Nines",
            "Knight's Fall",
            "Knightfall",
            "Lament",
            "Last Chance",
            "Last Laugh",
            "Last Rites",
            "Last Word",
            "Last Words",
            "Lazarus",
            "Legacy",
            "Legionaire",
            "Life's Limit",
            "Lightning",
            "Lightningflash",
            "Limbo",
            "Lockjaw",
            "Magma",
            "Malice",
            "Maneater",
            "Massacre",
            "Mercy",
            "Midnight",
            "Misery's End",
            "Moonsight",
            "Mortality",
            "Narcoleptic",
            "Night's Fall",
            "Nightbane",
            "Nightfall",
            "Nightmare",
            "Nighttime",
            "Nightwatch",
            "Nirvana",
            "Oathbreaker",
            "Oathkeeper",
            "Oblivion",
            "Ole Betsy",
            "Omega",
            "Optimist",
            "Orbit",
            "Party Pooper",
            "Patience",
            "Peacekeeper",
            "Peacemaker",
            "Pendulum",
            "Perfect Storm",
            "Persuasion",
            "Piety",
            "Popeye",
            "Pride",
            "Prophecy",
            "Pulse",
            "Punisher",
            "Purifier",
            "Rage",
            "Rapture",
            "Rattlesnake",
            "Reckoning",
            "Reign",
            "Remorse",
            "Requiem",
            "Retirement",
            "Rigormortis",
            "Salvation",
            "Salvo",
            "Scar",
            "Serenity",
            "Severance",
            "Shadowfury",
            "Shadowmoon",
            "Silence",
            "Snake",
            "Snapper",
            "Soulburn",
            "Sprocket",
            "Stalker",
            "Storm",
            "Storm Breaker",
            "Storm-Weaver",
            "Stormbringer",
            "Stormrider",
            "Sugar",
            "Sunshine",
            "Supernova",
            "Supremacy",
            "Suspension",
            "Swan Song",
            "Sweetie",
            "Syndrome",
            "Termination",
            "The Ambassador",
            "The Chancellor",
            "The End",
            "The Judge",
            "The Light",
            "The Oculus",
            "The Oracle",
            "The Pig",
            "The Void",
            "Thunder",
            "Thundercall",
            "Trauma",
            "Treachery",
            "Tremor",
            "Tribunal",
            "Tribute",
            "Trinity",
            "Trouble",
            "Twilight",
            "Typhoon",
            "Ubiquity",
            "Undoing",
            "Vacancy",
            "Valkyrie",
            "Vanquisher",
            "Vengeance",
            "Voice of Insanity",
            "Voice of Reason",
            "Warbringer",
            "Warmonger",
            "Whispers",
            "Whisperwind",
            "Wicked",
            "Widow Maker",
            "Willbreaker",
            "Wit's End",
            "Wolf",
        ]

        c = randrange(4)
        if c == 0:
            return choice(s1)
        elif c == 1:
            return choice(s2) + " " + choice(s4)
        elif c == 2:
            return choice(s2) + " " + choice(s3) + " " + choice(s4)
        elif c == 3:
            return choice(s7) + ", " + choice(s5) + " " + choice(s6)


class Guild(Store):
    @staticmethod
    def generate():
        nm1 = [
            "Acts",
            "Affliction",
            "Agony",
            "Allies",
            "Ambition",
            "Angels",
            "Anger",
            "Anguish",
            "Anomalies",
            "Archers",
            "Army",
            "Assassins",
            "Association",
            "Atonement",
            "Attack",
            "Avengers",
            "Avenging",
            "Ban",
            "Bandits",
            "Bane",
            "Beasts",
            "Betrayal",
            "Birth",
            "Blaze",
            "Blessing",
            "Blood",
            "Bond",
            "Boon",
            "Bounty",
            "Brigade",
            "Burden",
            "Butchers",
            "Champions",
            "Children",
            "Citizens",
            "Civilians",
            "Commandos",
            "Companions",
            "Conquerors",
            "Contract",
            "Corruption",
            "Courage",
            "Crew",
            "Crushers",
            "Cry",
            "Curse",
            "Damnation",
            "Dawn",
            "Deceivers",
            "Demons",
            "Desire",
            "Destiny",
            "Disciples",
            "Disruption",
            "Disturbance",
            "Division",
            "Dream",
            "Dreamers",
            "Duty",
            "End",
            "Enemies",
            "Enigmas",
            "Entities",
            "Evolution",
            "Executioners",
            "Faith",
            "Fame",
            "Favor",
            "Fiends",
            "Fight",
            "Fighters",
            "Flames",
            "Flash",
            "Flight",
            "Force",
            "Forgiveness",
            "Fortune",
            "Freaks",
            "Frenzy",
            "Gang",
            "Genocide",
            "Ghosts",
            "Gift",
            "Gladiators",
            "Glory",
            "Grace",
            "Grief",
            "Grudge",
            "Guardians",
            "Guards",
            "Hammers",
            "Harbingers",
            "Harmony",
            "Harvesters",
            "Hate",
            "Hell",
            "Heralds",
            "Heroes",
            "Home",
            "Honor",
            "Hope",
            "Horde",
            "Host",
            "House",
            "Howl",
            "Hunters",
            "Illusions",
            "Immortals",
            "Justice",
            "Keepers",
            "Killers",
            "Knights",
            "Last",
            "Legacy",
            "Legion",
            "Light",
            "Mages",
            "Masters",
            "Memories",
            "Men",
            "Mercenaries",
            "Messengers",
            "Might",
            "Minds",
            "Misery",
            "Monsters",
            "Mysteries",
            "Mystery",
            "Mystics",
            "Myth",
            "Nightmares",
            "Oath",
            "Oracles",
            "Order",
            "Outcasts",
            "Outlaws",
            "Outsiders",
            "Overseers",
            "Pact",
            "Pain",
            "Paladins",
            "Passion",
            "Patience",
            "Peace",
            "Phantoms",
            "Plague",
            "Promise",
            "Prophecies",
            "Prophets",
            "Protection",
            "Protectors",
            "Punishment",
            "Purification",
            "Pursuit",
            "Quiet",
            "Rage",
            "Raiders",
            "Rangers",
            "Rebellion",
            "Rebels",
            "Rebirth",
            "Recovery",
            "Recruits",
            "Redemption",
            "Refugees",
            "Rejects",
            "Relics",
            "Requiem",
            "Residents",
            "Retaliation",
            "Retribution",
            "Revelations",
            "Revenge",
            "Riddles",
            "Riders",
            "Rise",
            "Rivals",
            "Roar",
            "Rogues",
            "Ruins",
            "Rumours",
            "Sacrifice",
            "Safety",
            "Scourge",
            "Scouts",
            "Screams",
            "Screech",
            "Secret",
            "Secrets",
            "Seducers",
            "Seekers",
            "Seers",
            "Sentinels",
            "Serenity",
            "Service",
            "Shades",
            "Shadows",
            "Shamans",
            "Shame",
            "Shepherds",
            "Shields",
            "Silence",
            "Sinners",
            "Smiles",
            "Society",
            "Soldiers",
            "Sorcerers",
            "Spears",
            "Specters",
            "Spirits",
            "Spite",
            "Squad",
            "Stalkers",
            "Stewards",
            "Storm",
            "Strangers",
            "Strength",
            "Struggle",
            "Survivors",
            "Swarm",
            "Swords",
            "Tears",
            "Tempest",
            "Templars",
            "Terror",
            "Thieves",
            "Thugs",
            "Thunder",
            "Tirade",
            "Torment",
            "Tradition",
            "Traitors",
            "Tranquillity",
            "Treasure",
            "Trial",
            "Trust",
            "Vendetta",
            "Vengeance",
            "Venom",
            "Victims",
            "Vigor",
            "Vikings",
            "Villains",
            "Vision",
            "Visions",
            "Visitors",
            "Voice",
            "Voices",
            "Wards",
            "Warlords",
            "Warriors",
            "Wealth",
            "Weapons",
            "Weight",
            "Whisper",
            "Whispers",
            "Widows",
            "Witches",
            "Wizards",
            "Women",
            "Workers",
            "Wound",
            "Wraiths",
            "Wrath",
            "Yell",
        ]
        nm2 = [
            "from the Empire",
            "from the Forest",
            "from the Grave",
            "from the Mountains",
            "from the Ocean",
            "from the People",
            "from the Sea",
            "from the Woods",
            "of Abandonment",
            "of Ambition",
            "of Angels",
            "of Anger",
            "of Betrayal",
            "of Claws",
            "of Corruption",
            "of Courage",
            "of Damnation",
            "of Darkness",
            "of Death",
            "of Decay",
            "of Deception",
            "of Defiance",
            "of Delusion",
            "of Desire",
            "of Devotion",
            "of Disease",
            "of Ending",
            "of Extinction",
            "of Faith",
            "of Fear",
            "of Forests",
            "of Fortune",
            "of Fury",
            "of Hate",
            "of Heroes",
            "of Honor",
            "of Hope",
            "of Impurity",
            "of Innocence",
            "of Joy",
            "of Life",
            "of Light",
            "of Loyalty",
            "of Might",
            "of Mountains",
            "of Mystery",
            "of Mystics",
            "of Nature",
            "of Oceans",
            "of Patience",
            "of Promises",
            "of Purity",
            "of Rejects",
            "of Seduction",
            "of Serenity",
            "of Shadows",
            "of Shame",
            "of Skulls",
            "of Strength",
            "of Tricks",
            "of Trust",
            "of Vigor",
            "of Virtue",
            "of Wolves",
            "of the Abandoned",
            "of the Alligator",
            "of the Ambitious",
            "of the Angelic",
            "of the Angry",
            "of the Ape",
            "of the Badger",
            "of the Bear",
            "of the Betrayed",
            "of the Bitter",
            "of the Boar",
            "of the Bold",
            "of the Bound",
            "of the Brave",
            "of the Buffalo",
            "of the Bull",
            "of the Carious",
            "of the Cheeky",
            "of the Classified",
            "of the Claw",
            "of the Clean",
            "of the Cobra",
            "of the Collapsed",
            "of the Concealed",
            "of the Corrupt",
            "of the Corrupted",
            "of the Cosmos",
            "of the Cougar",
            "of the Covert",
            "of the Crocodile",
            "of the Crooked",
            "of the Crow",
            "of the Crumbled",
            "of the Damned",
            "of the Dark",
            "of the Dead",
            "of the Decayed",
            "of the Deceased",
            "of the Deceived",
            "of the Defiant",
            "of the Deluded",
            "of the Demonic",
            "of the Departed",
            "of the Depraved",
            "of the Deserted",
            "of the Desired",
            "of the Despicable",
            "of the Devoted",
            "of the Discarded",
            "of the Diseased",
            "of the Disgraceful",
            "of the Dishonest",
            "of the Dissipated",
            "of the Dog",
            "of the Dove",
            "of the Dragon",
            "of the Dragonfly",
            "of the Eager",
            "of the Eagle",
            "of the Earth",
            "of the Ended",
            "of the Enraged",
            "of the Extinct",
            "of the Faithful",
            "of the Fallen",
            "of the Fearless",
            "of the Feeble",
            "of the Fierce",
            "of the Forbidden",
            "of the Forest",
            "of the Forgotten",
            "of the Forsaken",
            "of the Fortunate",
            "of the Fox",
            "of the Furious",
            "of the Galaxy",
            "of the Gorilla",
            "of the Grave",
            "of the Ground",
            "of the Hallowed",
            "of the Hateful",
            "of the Hawk",
            "of the Heroic",
            "of the Hidden",
            "of the Holy",
            "of the Honest",
            "of the Honored",
            "of the Hopeful",
            "of the Horse",
            "of the Humble",
            "of the Ill",
            "of the Immoral",
            "of the Impure",
            "of the Infernal",
            "of the Innocent",
            "of the Jackal",
            "of the Jaguar",
            "of the Joyful",
            "of the Joyous",
            "of the Jungle",
            "of the Lake",
            "of the Lamb",
            "of the Land",
            "of the Last Age",
            "of the Lewd",
            "of the Light",
            "of the Lion",
            "of the Living",
            "of the Lost",
            "of the Lost Age",
            "of the Loyal",
            "of the Lynx",
            "of the Mace",
            "of the Meek",
            "of the Mental",
            "of the Mighty",
            "of the Mislead",
            "of the Moon",
            "of the Mountain",
            "of the Mysterious",
            "of the Mystical",
            "of the Natural",
            "of the Nefarious",
            "of the Night",
            "of the Noble",
            "of the Obscene",
            "of the Obscure",
            "of the Ocean",
            "of the Owl",
            "of the Passive",
            "of the Patient",
            "of the Perished",
            "of the Pious",
            "of the Poor",
            "of the Pristine",
            "of the Profane",
            "of the Promised",
            "of the Pure",
            "of the Putrid",
            "of the Ram",
            "of the Rat",
            "of the Raven",
            "of the Reckless",
            "of the Rejected",
            "of the Resolute",
            "of the Revenant",
            "of the Rhino",
            "of the Rich",
            "of the Right",
            "of the Righteous",
            "of the Rotten",
            "of the Ruined",
            "of the Sacred",
            "of the Sacrificed",
            "of the Scorpion",
            "of the Sea",
            "of the Seduced",
            "of the Serene",
            "of the Serpent",
            "of the Shadows",
            "of the Shameless",
            "of the Shark",
            "of the Sheep",
            "of the Shield",
            "of the Sick",
            "of the Sincere",
            "of the Skull",
            "of the Snake",
            "of the Sophisticated",
            "of the Spear",
            "of the Spider",
            "of the Stag",
            "of the Stars",
            "of the Stout",
            "of the Strong",
            "of the Sun",
            "of the Sword",
            "of the Taboo",
            "of the Tainted",
            "of the Talon",
            "of the Tame",
            "of the Tiger",
            "of the Tricked",
            "of the Trusted",
            "of the Undead",
            "of the Universe",
            "of the Unknown",
            "of the Valiant",
            "of the Vanquished",
            "of the Vicious",
            "of the Vigorous",
            "of the Virtuous",
            "of the Void",
            "of the Vulture",
            "of the Wasted",
            "of the Weak",
            "of the Weasel",
            "of the Wicked",
            "of the Withered",
            "of the Wolf",
            "of the Wolves",
            "of the Woods",
            "of the World",
            "of the Wretched",
            "of the Wrong",
        ]
        nm3 = [
            "Aqua",
            "Arm",
            "Banner",
            "Battle",
            "Bellow",
            "Black",
            "Blood",
            "Blue",
            "Bone",
            "Boulder",
            "Bright",
            "Bronze",
            "Burning",
            "Chaos",
            "Char",
            "Cold",
            "Cunning",
            "Dark",
            "Dashing",
            "Doom",
            "Drum",
            "Earth",
            "Ebon",
            "Fallen",
            "Fel",
            "Fire",
            "Forge",
            "Forsaken",
            "Frost",
            "Gentle",
            "Golden",
            "Gray",
            "Hallow",
            "Hell",
            "High",
            "Hollow",
            "Howling",
            "Humming",
            "Iron",
            "Ivory",
            "Jade",
            "Killing",
            "Lightning",
            "Low",
            "Mad",
            "Magic",
            "Marble",
            "Metal",
            "Midnight",
            "Monster",
            "Moon",
            "Night",
            "Poison",
            "Quick",
            "Rain",
            "Raven",
            "Red",
            "Rumble",
            "Running",
            "Shadow",
            "Shatter",
            "Shimmer",
            "Shiver",
            "Silver",
            "Snow",
            "Solar",
            "Split",
            "Steel",
            "Stone",
            "Storm",
            "Sun",
            "Swift",
            "Thunder",
            "Tremble",
            "Twin",
            "Venom",
            "Water",
            "White",
            "Wind",
            "Wrecking",
        ]
        nm4 = [
            " Assault",
            " Dragons",
            " Eagles",
            " Foxes",
            " Hawks",
            " Hearts",
            " Lust",
            " Maggots",
            " Oath",
            " Rage",
            " Rats",
            " Wolves",
            "arrows",
            "bane",
            "beards",
            "blades",
            "bow",
            "brand",
            "brawlers",
            "breaker",
            "brows",
            "cloaks",
            "clouds",
            "crawlers",
            "crushers",
            "cry",
            "dawn",
            "death",
            "fall",
            "field",
            "fists",
            "flags",
            "flayers",
            "force",
            "ford",
            "forge",
            "fury",
            "garde",
            "glades",
            "guard",
            "guards",
            "hammers",
            "hands",
            "hoods",
            "landers",
            "laws",
            "light",
            "manes",
            "mantles",
            "might",
            "pikes",
            "roses",
            "scars",
            "shade",
            "shapers",
            "shields",
            "shifters",
            "shroud",
            "sins",
            "skulls",
            "smiths",
            "song",
            "stars",
            "stand",
            "striders",
            "swords",
            "talons",
            "thorn",
            "tops",
            "tips",
            "vale",
            "well",
        ]
        nm5 = [
            "Abandoned",
            "Accurate",
            "Alchemy",
            "Alpha",
            "Ambitious",
            "Amused",
            "Angelic",
            "Angry",
            "Arcane",
            "Aspiring",
            "Assassins",
            "Assorted",
            "Awful",
            "Banished",
            "Betrayed",
            "Bite-sized",
            "Bitter",
            "Black",
            "Blades",
            "Blue",
            "Bold",
            "Bound",
            "Bounty",
            "Brave",
            "Broken",
            "Burning",
            "Chosen",
            "Clean",
            "Closed",
            "Collapsed",
            "Common",
            "Concealed",
            "Contract",
            "Corrupt",
            "Corrupted",
            "Crescent",
            "Crimson",
            "Crumbled",
            "Cutlass",
            "Damned",
            "Dark",
            "Dazzling",
            "Decayed",
            "Deceased",
            "Deceived",
            "Defiant",
            "Delicate",
            "Deluded",
            "Demolition",
            "Demonic",
            "Departed",
            "Depraved",
            "Deserted",
            "Desired",
            "Despicable",
            "Devoted",
            "Discarded",
            "Diseased",
            "Disgraceful",
            "Dishonest",
            "Dispensable",
            "Divided",
            "Electric",
            "Elite",
            "Emerald",
            "Encircling",
            "Enraged",
            "Eternal",
            "Ethereal",
            "Extra-Small",
            "Faded",
            "Fallen",
            "Famous",
            "Fast",
            "Fearless",
            "Fierce",
            "Flesh",
            "Fluttering",
            "Forbidden",
            "Forgotten",
            "Forsaken",
            "Fortunate",
            "Funny",
            "Furious",
            "Golden",
            "Grave",
            "Grouchy",
            "Grubby",
            "Hallowed",
            "Harmonious",
            "Heavens",
            "Hellfire",
            "Heroic",
            "Hidden",
            "High",
            "Holy",
            "Honest",
            "Honored",
            "Hopeful",
            "Humble",
            "Icky",
            "Ill",
            "Immoral",
            "Impure",
            "Independent",
            "Infamous",
            "Infernal",
            "Innocent",
            "Iron",
            "Itchy",
            "Jolly",
            "Joyful",
            "Joyous",
            "Jumpy",
            "Large",
            "Last",
            "Living",
            "Lost",
            "Macabre",
            "Massive",
            "Mental",
            "Mighty",
            "Mini",
            "Mislead",
            "Moonlight",
            "Mortal",
            "Mysterious",
            "Mystic",
            "Mystical",
            "Nameless",
            "Nefarious",
            "Noble",
            "Nocturnal",
            "Obscene",
            "Obscure",
            "Omega",
            "Ominous",
            "Open",
            "Ordained",
            "Ordinary",
            "Perished",
            "Phobic",
            "Pious",
            "Power",
            "Pristine",
            "Profane",
            "Promised",
            "Pure",
            "Purple",
            "Putrid",
            "Reckless",
            "Red",
            "Rejected",
            "Resolute",
            "Revenant",
            "Righteous",
            "Rising",
            "Roaring",
            "Robust",
            "Rogue",
            "Rotten",
            "Royal",
            "Ruined",
            "Sacred",
            "Sacrificed",
            "Scarlet",
            "Scary",
            "Scourge",
            "Sealed",
            "Searing",
            "Sedated",
            "Shaded",
            "Shadow",
            "Shameless",
            "Shattered",
            "Shivering",
            "Sightless",
            "Silent",
            "Sleeping",
            "Sore",
            "Super",
            "Tainted",
            "Tasty",
            "Tempest",
            "Templar",
            "Tricked",
            "Trusted",
            "Twilight",
            "Tyranny",
            "Ugly",
            "Unarmed",
            "Unknown",
            "Unseen",
            "Valiant",
            "Vanquished",
            "Vicious",
            "Vigorous",
            "Virtuous",
            "Vulgar",
            "Wasted",
            "Weak",
            "Wicked",
            "Winged",
            "Withered",
            "World",
            "Worthless",
            "Wretched",
            "Wrong",
            "Grim",
        ]
        nm6 = [
            "Admirals",
            "Alliance",
            "Ancients",
            "Anomalies",
            "Apocalypse",
            "Ashes",
            "Assailant",
            "Assassins",
            "Assault",
            "Berserkers",
            "Blow",
            "Brigade",
            "Brothers",
            "Butchers",
            "Champions",
            "Chaos",
            "Criminals",
            "Crossfire",
            "Crusaders",
            "Death",
            "Defeat",
            "Demons",
            "Devils",
            "Discipline",
            "Domination",
            "Dominion",
            "Doom",
            "Dust",
            "Dynasty",
            "Embers",
            "End",
            "Enemy",
            "Entities",
            "Executors",
            "Exiles",
            "Exterminators",
            "Fall",
            "Feast",
            "Force",
            "Gang",
            "Gangsters",
            "Genesis",
            "Genocide",
            "Gods",
            "Grave",
            "Gunslingers",
            "Harvesters",
            "Headhunters",
            "Helix",
            "Honour",
            "Hooligans",
            "Hunters",
            "Illusions",
            "Immortals",
            "Inferno",
            "Intent",
            "Jackals",
            "Killers",
            "Knights",
            "Legacy",
            "Legion",
            "Liquidators",
            "Mafia",
            "Maggots",
            "Moguls",
            "Nightmare",
            "Noobs",
            "Oblivion",
            "Occupation",
            "Outlaws",
            "Paradox",
            "Perception",
            "Pergatory",
            "Plague",
            "Power",
            "Predation",
            "Predators",
            "Prestige",
            "Primeval",
            "Privilege",
            "Punished",
            "Punks",
            "Rage",
            "Rebels",
            "Regiment",
            "Sacrament",
            "Saints",
            "Serenity",
            "Shadow",
            "Shadows",
            "Sharpshooters",
            "Singularity",
            "Slayers",
            "Soldiers",
            "Squad",
            "Strategy",
            "Supremacy",
            "Switchblades",
            "Syndicate",
            "Synergy",
            "Thugs",
            "Thunder",
            "Titans",
            "Tyranny",
            "Valor",
            "Vanguard",
            "Vanguardians",
            "Vanguards",
            "Vengeance",
            "Veterans",
            "Vigor",
            "Vigorous",
            "Vikings",
            "Vitality",
            "Voltiac",
            "Vultures",
            "War",
            "Warfare",
            "Warheads",
            "Widowmakers",
            "Wolverines",
            "Wound",
            "Incarnation",
        ]

        n = randrange(2)
        if n == 0:
            return choice(nm1) + " " + choice(nm2)
        elif n == 1:
            return choice(nm3) + " " + choice(nm4)
        elif n == 2:
            return choice(nm5) + " " + choice(nm6)



from abc import abstractmethod, ABCMeta


class Character(metaclass=ABCMeta):
    @staticmethod
    @abstractmethod
    def generate():
        pass

    def __str__(self):
        return self.generate()

    def __repr__(self):
        return self.generate()

    def __iter__(self):
        return self

    def __next__(self):
        return self.generate()


class Store(metaclass=ABCMeta):
    @staticmethod
    @abstractmethod
    def generate():
        pass

    def __str__(self):
        return self.generate()

    def __repr__(self):
        return self.generate()

    def __iter__(self):
        return self

    def __next__(self):
        return self.generate()


class Item(metaclass=ABCMeta):
    @staticmethod
    @abstractmethod
    def generate():
        pass

    def __str__(self):
        return self.generate()

    def __repr__(self):
        return self.generate()

    def __iter__(self):
        return self

    def __next__(self):
        return self.generate()
